(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    527631,      13766]
NotebookOptionsPosition[    525402,      13700]
NotebookOutlinePosition[    525868,      13718]
CellTagsIndexPosition[    525825,      13715]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{"Print", "[", "\"\<ANT Version: 1.1 ( 28 Mar 2014).\>\"", "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<Authors: Paul W. Angel, Yi Cai, Nicholas L. Rodd, Michael A. Schmidt, \
Raymond R. Volkas\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Please cite: arXiv:1308.0463.\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<http://ant.hepforge.org\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<The package ANT is written for Mathematica 8 and higher and it is \
distributed under the terms of GNU Public License \
http://www.gnu.org/copyleft/gpl.html\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<Use ANT[expr] to evaluate the Passarino-Veltman functions contained \
in expr to its finite part in the limit of vanishing external momenta. \
Besides the function ANT, it defines the functions A0ant, B0ant, C0ant as \
well as D0ant, which take the same arguments as A0, B0i, C0i and D0i, \
respectively, and return the finite part of the PV function in the limit of \
external momenta.\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
  "Print", "[", 
   "\"\<Note that the package ANT has to be loaded after FormCalc\>\"", "]"}],
   ";"}]}], "Code",
 CellChangeTimes->{{3.583540052894446*^9, 3.583540083269858*^9}, {
  3.583540224246677*^9, 3.583540363745657*^9}, {3.5835447010814734`*^9, 
  3.583544709126947*^9}, {3.58354489393762*^9, 3.583544894402194*^9}, {
  3.583558221567185*^9, 3.583558255621214*^9}, {3.583558481267511*^9, 
  3.583558558101913*^9}, {3.583558644770945*^9, 3.58355868181601*^9}, {
  3.58355895629965*^9, 3.5835589784245853`*^9}, {3.5846473106213083`*^9, 
  3.5846473362496967`*^9}, {3.584650280372034*^9, 3.584650281477983*^9}, {
  3.604972655226996*^9, 3.604972661411042*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BeginPackage", "[", "\"\<ANT`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "ANT", ",", "A0ant", ",", "B0ant", ",", "C0ant", ",", "D0ant", ",", " ", 
    "AFant", ",", "AFDant", ",", "BFant", ",", "BFDant", ",", "CFant", ",", 
    "CFDant", ",", "DFant", ",", "DFDant"}], "}"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ANT", "::", "usage"}], "=", 
  "\"\<The function ANT can be applied to any expression expr, e.g. \
ANT[expr], and it replaces all Passarino-Veltman functions (as defined by \
FormCalc/LoopTools) by the evaluated expression in the limit of vanishing \
external momenta. For the PV functions B0, B1, C0, C1, C2, C00, it also \
returns the expansion of the PV function up to the first derivatives with \
respect to the momenta.\>\""}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"A0ant", "::", "usage"}], "=", 
   "\"\<A0ant[\!\(\*SuperscriptBox[\(m\), \(2\)]\)] returns the finite part \
of \!\(\*SubscriptBox[\(A\), \(0\)]\)(\!\(\*SuperscriptBox[\(m\), \(2\)]\))\>\
\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"B0ant", "::", "usage"}], "=", 
   "\"\<B0ant[id,\!\(\*SuperscriptBox[\(p\), \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(2\)], \(2\)]\)] returns \
the finite part of \!\(\*SubscriptBox[\(B\), \
\(id\)]\)(\!\(\*SuperscriptBox[\(p\), \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(2\)], \(2\)]\)) in the \
limit of vanishing external momenta. Additionally, it returns the first \
derivative of \!\(\*SubscriptBox[\(B\), \(0\)]\) as well as \
\!\(\*SubscriptBox[\(B\), \(1\)]\).\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"C0ant", "::", "usage"}], "=", 
   "\"\<C0ant[id,\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(1\)], \(2\)]\),\!\
\(\*SuperscriptBox[SubscriptBox[\(p\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(12\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(3\)], \(2\)]\)] returns \
the finite part of \!\(\*SubscriptBox[\(C\), \
\(id\)]\)(\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(12\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(3\)], \(2\)]\)) in the \
limit of vanishing external momenta. Additionally, it returns the first \
derivative of \!\(\*SubscriptBox[\(C\), \(0\)]\), \!\(\*SubscriptBox[\(C\), \
\(1\)]\), \!\(\*SubscriptBox[\(C\), \(2\)]\) as well as \
\!\(\*SubscriptBox[\(C\), \(00\)]\).\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D0ant", "::", "usage"}], "=", 
    "\"\<D0ant[id,\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(3\)], \(2\)]\), \
\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(4\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(12\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(23\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(3\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(4\)], \(2\)]\)] returns \
the finite part of \!\(\*SubscriptBox[\(D\), \
\(id\)]\)(\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(3\)], \(2\)]\), \
\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(4\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(12\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(23\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(1\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(2\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(3\)], \
\(2\)]\),\!\(\*SuperscriptBox[SubscriptBox[\(m\), \(4\)], \(2\)]\)) in the \
limit of vanishing external momenta.\>\""}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EndPackage", "[", "]"}], ";"}], "\[IndentingNewLine]"}], "Code",
 CellChangeTimes->{{3.5835612318810577`*^9, 3.583561310002359*^9}, {
   3.58356134005193*^9, 3.5835613443788643`*^9}, {3.583561385820898*^9, 
   3.583561387219994*^9}, 3.583561511643231*^9, {3.5835615451506233`*^9, 
   3.583561550328377*^9}}],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.583558853278582*^9, 3.583558860157151*^9}, {
  3.583561330261446*^9, 3.5835613327085733`*^9}}],

Cell[CellGroupData[{

Cell["A", "Subsection",
 CellChangeTimes->{{3.5835336627484703`*^9, 3.583533670118494*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"AFant", "[", "ms_", "]"}], ":=", 
   RowBox[{"ms", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Log", "[", "ms", "]"}]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AFant", "[", "0", "]"}], ":=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"AFDant", "[", "ms_", "]"}], ":=", "0"}], ";"}]}], "Code",
 CellChangeTimes->{{3.583465777661751*^9, 3.583465791776717*^9}, {
   3.583465902690593*^9, 3.583465911178903*^9}, {3.583465987281157*^9, 
   3.583465988337179*^9}, {3.583466862174767*^9, 3.583466867188094*^9}, 
   3.583481416752515*^9, {3.583481831684901*^9, 3.583481838728592*^9}, {
   3.583533703478862*^9, 3.583533715136063*^9}, {3.583541300198907*^9, 
   3.583541306278893*^9}, {3.583543461575186*^9, 3.5835434790388393`*^9}, {
   3.583558689227635*^9, 3.5835587048997717`*^9}, {3.583558753712611*^9, 
   3.583558754038821*^9}, {3.58355962460071*^9, 3.58355962485917*^9}, {
   3.583560110659339*^9, 3.583560112563837*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["B", "Subsection",
 CellChangeTimes->{{3.5835336627484703`*^9, 3.583533676140601*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BFant", "[", 
    RowBox[{"LoopTools`bb0", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"SameQ", "[", 
      RowBox[{"m1s", ",", "m2s"}], "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Log", "[", "m1s", "]"}]}], ",", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{
        RowBox[{"m1s", " ", 
         RowBox[{"Log", "[", "m1s", "]"}]}], "-", 
        RowBox[{"m2s", " ", 
         RowBox[{"Log", "[", "m2s", "]"}]}]}], 
       RowBox[{"m1s", "-", "m2s"}]]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BFDant", "[", 
    RowBox[{"LoopTools`bb0", ",", "ps_", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t", "=", 
       FractionBox["m2s", "m1s"]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], ",", 
        FractionBox["ps", 
         RowBox[{"6", " ", "m2s"}]], ",", 
        RowBox[{
         FractionBox["ps", "m2s"], 
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["t", "2"], "-", 
           RowBox[{"2", " ", "t", " ", 
            RowBox[{"Log", "[", "t", "]"}]}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t"}], ")"}], "3"]}]]}]}], "]"}]}]}], 
    "]"}]}], ";"}]}], "Code",
 CellChangeTimes->{{3.564381140660962*^9, 3.564381150185349*^9}, {
  3.583465968453168*^9, 3.5834659824370604`*^9}, {3.583466067794704*^9, 
  3.583466073426304*^9}, {3.58346615121063*^9, 3.583466152927438*^9}, {
  3.583533725862995*^9, 3.583533734710492*^9}, {3.583541424228936*^9, 
  3.583541430863427*^9}, {3.58354147736302*^9, 3.583541482948461*^9}, {
  3.58356010045755*^9, 3.58356010474932*^9}, {3.583561582909339*^9, 
  3.583561593555624*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BFant", "[", 
    RowBox[{"LoopTools`bb1", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t", "=", 
       FractionBox["m2s", "m1s"]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], ",", 
        FractionBox[
         RowBox[{"Log", "[", "m1s", "]"}], "2"], ",", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], 
          RowBox[{"Log", "[", "m1s", "]"}]}], "+", 
         FractionBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"4", "t"}], "-", 
           SuperscriptBox["t", "2"], "-", 
           RowBox[{"4", "t", " ", 
            RowBox[{"Log", "[", "t", "]"}]}], "+", 
           RowBox[{"2", 
            SuperscriptBox["t", "2"], 
            RowBox[{"Log", "[", "t", "]"}]}]}], 
          RowBox[{"4", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t"}], ")"}], "2"]}]]}]}], "]"}]}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BFDant", "[", 
    RowBox[{"LoopTools`bb1", ",", "ps_", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t", "=", 
       FractionBox["m2s", "m1s"]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], ",", 
        RowBox[{"-", 
         FractionBox["ps", 
          RowBox[{"12", "m2s"}]]}], ",", 
        RowBox[{
         FractionBox["ps", "m2s"], 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t"}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"t", " ", 
               RowBox[{"(", 
                RowBox[{"5", "+", 
                 RowBox[{"2", " ", "t"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["t", "2"], " ", 
            RowBox[{"Log", "[", "t", "]"}]}]}], 
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t"}], ")"}], "4"]}]]}]}], "]"}]}]}], 
    "]"}]}], ";"}]}], "Code",
 CellChangeTimes->{{3.56438112611067*^9, 3.5643811272869387`*^9}, {
  3.583466319601182*^9, 3.583466321112935*^9}, {3.583469577135501*^9, 
  3.583469591853033*^9}, {3.5835337424701138`*^9, 3.583533746140956*^9}, {
  3.583541434632868*^9, 3.58354147332614*^9}, {3.583561590951787*^9, 
  3.583561592458576*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BFant", "[", 
     RowBox[{"LoopTools`bb00", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "t", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"t", "=", 
        FractionBox["m2s", "m1s"]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"SameQ", "[", 
          RowBox[{"m1s", ",", "m2s"}], "]"}], ",", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], "m1s", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"Log", "[", "m1s", "]"}]}], ")"}]}], ",", 
         RowBox[{
          FractionBox["1", "8"], "m1s", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"3", " ", "t"}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "t"}], ")"}], " ", 
             RowBox[{"Log", "[", "m1s", "]"}]}], "-", 
            FractionBox[
             RowBox[{"2", " ", 
              SuperscriptBox["t", "2"], " ", 
              RowBox[{"Log", "[", "t", "]"}]}], 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t"}]]}], ")"}]}]}], "]"}]}]}], 
     "]"}]}], ";"}], "\n", "\[IndentingNewLine]"}]], "Code",
 CellChangeTimes->{
  3.5834690862096786`*^9, {3.583469601055789*^9, 3.583469606413494*^9}, {
   3.583470572144562*^9, 3.5834705733267307`*^9}, {3.583533749116647*^9, 
   3.5835337548326797`*^9}, {3.583541440967432*^9, 3.5835414667955217`*^9}, {
   3.583541536861*^9, 3.583541582695077*^9}, {3.583541633320166*^9, 
   3.5835416359068613`*^9}, 3.583541910276249*^9, 3.583561596282721*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BFant", "[", 
    RowBox[{"LoopTools`bb11", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "t", "}"}], ",", 
     RowBox[{
      RowBox[{"t", "=", 
       FractionBox["m2s", "m1s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"m1s", "===", "m2s"}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"Log", "[", "m1s", "]"}], "3"]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "3"]}], 
          RowBox[{"Log", "[", "m1s", "]"}]}], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t"}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{"11", "+", 
              RowBox[{"t", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "7"}], "+", 
                 RowBox[{"2", " ", "t"}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", "t", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "t"}], ")"}], " ", "t"}]}], ")"}], 
            " ", 
            RowBox[{"Log", "[", "t", "]"}]}]}], 
          RowBox[{"18", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t"}], ")"}], "3"]}]]}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.583469738925688*^9, 3.583469769856967*^9}, {
   3.583470538340539*^9, 3.583470543084312*^9}, {3.583533758593829*^9, 
   3.58353376509035*^9}, {3.583541445312372*^9, 3.583541462101274*^9}, {
   3.5835415952466307`*^9, 3.58354163005989*^9}, {3.583541941047344*^9, 
   3.5835419420865917`*^9}, 3.583561599282291*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BFDant", "[", 
    RowBox[{"id_", ",", "ps_", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Derivative for B0i[\>\"", ",", "id", ",", 
        "\"\<] not defined\>\""}], "]"}], ";", "\n", 
      RowBox[{
       RowBox[{"B0i", "[", 
        RowBox[{"id", ",", "ps", ",", "m1s", ",", "m2s"}], "]"}], "-", 
       RowBox[{"BFant", "[", 
        RowBox[{"id", ",", "m1s", ",", "m2s"}], "]"}]}]}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellChangeTimes->{{3.583541916530662*^9, 3.583541929458138*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["C", "Subsection",
 CellChangeTimes->{{3.5835336627484703`*^9, 3.58353368093254*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc0", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s123", ",", " ", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"2", "m3s"}]]}], ",", "\[IndentingNewLine]", "s12", ",", 
        FractionBox[
         RowBox[{"1", "-", "t1", "+", 
          RowBox[{"Log", "[", "t1", "]"}]}], 
         RowBox[{"m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"]}]], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2", "-", 
          RowBox[{"t2", " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}]], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", "t1", "-", 
          RowBox[{"t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", " ", 
        RowBox[{
         FractionBox["1", "m3s"], 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"t1", "-", 
              RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
            RowBox[{"Log", "[", "t2", "]"}]}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}]}]]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc0", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", ",",
      "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"p12s", "+", "p1s", "+", "p2s"}], 
          RowBox[{"24", " ", 
           SuperscriptBox["m3s", "2"]}]]}], ",", "\[IndentingNewLine]", "s12",
         ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"12", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", "t1"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{"p12s", "+", "p2s"}], ")"}], " ", "t1", " ", 
               RowBox[{"(", 
                RowBox[{"5", "+", "t1"}], ")"}]}], "+", 
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "-", 
                 RowBox[{"5", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{"p12s", "-", "p1s", "+", "p2s", "+", 
              RowBox[{"2", " ", "p12s", " ", "t1"}], "+", 
              RowBox[{"2", " ", "p2s", " ", "t1"}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{"-", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"12", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                RowBox[{"(", 
                 RowBox[{"p1s", "+", "p2s"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"5", " ", "t2"}]}], ")"}]}], "+", 
               RowBox[{"p12s", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"5", " ", "t2"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"6", " ", "t2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "p12s"}], " ", "t2"}], "+", 
               RowBox[{"p1s", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", "t2"}], ")"}]}], "+", 
               RowBox[{"p2s", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", "t2"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"12", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"p2s", "-", 
              RowBox[{"5", " ", "p2s", " ", "t1"}], "-", 
              RowBox[{"2", " ", "p2s", " ", 
               SuperscriptBox["t1", "2"]}], "+", 
              RowBox[{"3", " ", "p12s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"5", " ", "t1"}]}], ")"}]}], "+", 
              RowBox[{"3", " ", "p1s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"5", " ", "t1"}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"6", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "p2s"}], " ", "t1"}], "+", 
              RowBox[{"p12s", " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", "t1"}], ")"}]}], "+", 
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", "t1"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"p12s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "t1"}], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "+", 
                 SuperscriptBox["t1", "2"], "-", 
                 RowBox[{"2", " ", "t2"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               RowBox[{"Log", "[", "t1", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["t1", "2"]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}]}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
                    
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"p1s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"t1", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "2"], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t1"}], ")"}], " ", "t2"}]}], 
                ")"}], " ", 
               RowBox[{"Log", "[", "t1", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["t1", "2"], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", " ", "t1"}]}], ")"}], " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}]}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}], " ", 
                  RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"p2s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
               RowBox[{"Log", "[", "t1", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "-", 
                    RowBox[{"t1", " ", "t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["t1", "2"]}], "-", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
                  RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}]}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "]"}]}], ";"}]}], "Code",
 CellChangeTimes->{{3.564450727597762*^9, 3.564450727914755*^9}, {
  3.5834698534832497`*^9, 3.583469862442697*^9}, {3.583471079571969*^9, 
  3.583471087384457*^9}, {3.5835337919066553`*^9, 3.58353379747509*^9}, {
  3.583541656161584*^9, 3.583541674289687*^9}, {3.58356009387389*^9, 
  3.583560096189542*^9}, {3.583561603472848*^9, 3.5835616069174957`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc1", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        FractionBox["1", 
         RowBox[{"6", "m3s"}]], ",", "\[IndentingNewLine]", "s12", ",", 
        FractionBox[
         RowBox[{"3", "-", 
          RowBox[{"4", "t1"}], "+", 
          SuperscriptBox["t1", "2"], "+", 
          RowBox[{"2", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", "m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["t2", "2"], "-", 
          RowBox[{"2", "t2", " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"2", "m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", "t1"}], "-", 
          RowBox[{"3", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"2", 
           SuperscriptBox["t1", "2"], 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", "m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         FractionBox["1", "m3s"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["t1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}]}], "+", "t2"}], 
                 ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}]}]}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc1", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", ",",
      "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s123", ",", 
        FractionBox[
         RowBox[{"p12s", "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"p1s", "+", "p2s"}], ")"}]}]}], 
         RowBox[{"120", " ", 
          SuperscriptBox["m3s", "2"]}]], ",", "\[IndentingNewLine]", "s12", 
        ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"36", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"], " ", "t1"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"p12s", "+", 
                 RowBox[{"2", " ", "p2s"}]}], ")"}], " ", "t1", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "17"}], "-", 
                 RowBox[{"8", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}], "+", 
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 RowBox[{"13", " ", "t1"}], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["t1", "2"]}], "+", 
                 SuperscriptBox["t1", "3"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{"p12s", "-", 
              RowBox[{"2", " ", "p1s"}], "+", 
              RowBox[{"2", " ", "p2s"}], "+", 
              RowBox[{"3", " ", "p12s", " ", "t1"}], "+", 
              RowBox[{"6", " ", "p2s", " ", "t1"}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{"-", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"36", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "6"}], " ", 
                RowBox[{"(", 
                 RowBox[{"p1s", "+", "p2s"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{"10", " ", "t2"}], "+", 
                  SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
               RowBox[{"p12s", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"8", " ", "t2"}], "+", 
                  RowBox[{"17", " ", 
                   SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{"6", " ", "t2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", " ", "p1s", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
               RowBox[{"6", " ", "p2s", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "t2"}], ")"}]}], "-", 
               RowBox[{"p12s", " ", "t2", " ", 
                RowBox[{"(", 
                 RowBox[{"3", "+", "t2"}], ")"}]}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"36", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"p12s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"8", " ", "t1"}], "-", 
                 RowBox[{"17", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", "p1s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"8", " ", "t1"}], "+", 
                 RowBox[{"17", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}], "+", 
              RowBox[{"p2s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"5", " ", "t1"}], "+", 
                 RowBox[{"13", " ", 
                  SuperscriptBox["t1", "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["t1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "p2s", " ", "t1"}], "+", 
              RowBox[{"p12s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "t1"}], ")"}]}], "+", 
              RowBox[{"2", " ", "p1s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "t1"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"6", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], "p12s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["t1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t1", "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t2"}], "+", 
               RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t2", "3"]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "t2"}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "+", 
                  RowBox[{"t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         
         RowBox[{
          FractionBox["1", 
           RowBox[{"6", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], "p2s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["t1", "3"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t2", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"5", "+", "t2"}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"11", "+", 
                    RowBox[{"7", " ", "t2"}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "-", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"14", "+", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", "t2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", 
                   SuperscriptBox["t1", "3"]}], "-", 
                  RowBox[{
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}], "+", 
                  RowBox[{"t1", " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "-", 
                    RowBox[{"3", " ", "t2"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    SuperscriptBox["t2", "3"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         
         RowBox[{
          FractionBox["1", 
           RowBox[{"6", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], "p1s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["t1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t2"}], "+", 
               RowBox[{"2", " ", "t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t2", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"7", " ", "t2"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", "t2", "-", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "-", 
                    RowBox[{"9", " ", "t2"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", "t2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "t1"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "t2"}], ")"}], " ", 
                   SuperscriptBox["t2", "2"]}], "-", 
                  SuperscriptBox["t2", "3"], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"3", " ", "t2"}], "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]}], "Code",
 CellChangeTimes->{
  3.5641732457370033`*^9, {3.564450885201185*^9, 3.5644508863128347`*^9}, {
   3.583469894759841*^9, 3.583469895526142*^9}, {3.583470033053873*^9, 
   3.58347003739081*^9}, {3.5834710874520893`*^9, 3.583471087498954*^9}, {
   3.58353380441129*^9, 3.583533808864438*^9}, {3.583541666592675*^9, 
   3.583541687393985*^9}, {3.583561609808333*^9, 3.583561612937435*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc2", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        FractionBox["1", 
         RowBox[{"6", "m3s"}]], ",", "\[IndentingNewLine]", "s12", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["t1", "2"], "-", 
          RowBox[{"2", "t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"2", "m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", "t2"}], "-", 
          RowBox[{"3", 
           SuperscriptBox["t2", "2"]}], "+", 
          RowBox[{"2", 
           SuperscriptBox["t2", "2"], 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"4", "m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"4", "t1"}], "-", 
          RowBox[{"3", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"2", 
           SuperscriptBox["t1", "2"], 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", "m3s", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", "m3s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc2", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", ",",
      "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s123", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"2", " ", "p12s"}], "+", "p1s", "+", 
          RowBox[{"2", " ", "p2s"}]}], 
         RowBox[{"120", " ", 
          SuperscriptBox["m3s", "2"]}]], ",", "\[IndentingNewLine]", "s12", 
        ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"36", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "17"}], "-", 
                 RowBox[{"8", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}], "+", 
              RowBox[{"6", " ", "p12s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"10", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}], "+", 
              RowBox[{"6", " ", "p2s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"10", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"p1s", "+", 
              RowBox[{"3", " ", "p1s", " ", "t1"}], "-", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{"p12s", "+", "p2s"}], ")"}], " ", "t1", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t1"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"36", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"p1s", "+", 
                  RowBox[{"2", " ", "p2s"}]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"8", " ", "t2"}], "+", 
                 RowBox[{"17", " ", 
                  SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
              RowBox[{"p12s", " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"5", " ", "t2"}], "+", 
                 RowBox[{"13", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["t2", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "p12s", " ", "t2"}], "+", 
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "t2"}], ")"}]}], "+", 
              RowBox[{"2", " ", "p2s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "t2"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"36", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"p1s", "+", "p2s", "-", 
              RowBox[{"8", " ", "p1s", " ", "t1"}], "-", 
              RowBox[{"5", " ", "p2s", " ", "t1"}], "-", 
              RowBox[{"17", " ", "p1s", " ", 
               SuperscriptBox["t1", "2"]}], "+", 
              RowBox[{"13", " ", "p2s", " ", 
               SuperscriptBox["t1", "2"]}], "+", 
              RowBox[{"3", " ", "p2s", " ", 
               SuperscriptBox["t1", "3"]}], "-", 
              RowBox[{"2", " ", "p12s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"8", " ", "t1"}], "+", 
                 RowBox[{"17", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["t1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "p2s", " ", "t1"}], "+", 
              RowBox[{"2", " ", "p12s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "t1"}], ")"}]}], "+", 
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", "t1"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         RowBox[{
          FractionBox["1", 
           RowBox[{"6", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], "p12s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["t1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "t1"}], "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t2"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                  RowBox[{"t1", " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t2", "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"9", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t2", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
                SuperscriptBox["t2", "3"], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         
         RowBox[{
          FractionBox["1", 
           RowBox[{"6", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], "p1s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["t1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t1", "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t2"}], "+", 
               RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t2", "3"]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "t2"}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "+", 
                  RowBox[{"t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
         
         RowBox[{
          FractionBox["1", 
           RowBox[{"6", " ", 
            SuperscriptBox["m3s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], "p2s", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["t1", "3"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t2"}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"5", " ", "t2"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "-", 
                  RowBox[{"t1", " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2", "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "t1"}], "-", 
                  RowBox[{"t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "t2"}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}]}]}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "Code",
 CellChangeTimes->{
  3.564173267282775*^9, {3.56445103140602*^9, 3.56445104680761*^9}, {
   3.583470045353985*^9, 3.583470052374927*^9}, {3.583471087578004*^9, 
   3.5834710876403093`*^9}, {3.583533813411162*^9, 3.583533818278617*^9}, {
   3.583541698275198*^9, 3.583541709531886*^9}, {3.583561615527212*^9, 
   3.583561618721994*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc00", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], 
   ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"Log", "[", "m3s", "]"}], "4"]}], ",", 
        "\[IndentingNewLine]", "s12", ",", 
        FractionBox[
         RowBox[{"3", "-", 
          RowBox[{"4", " ", "t1"}], "+", 
          SuperscriptBox["t1", "2"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"Log", "[", "m3s", "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "t1"}], ")"}], " ", "t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"]}]], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "t2"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           RowBox[{"Log", "[", "m3s", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}]], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "t1"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"Log", "[", "m3s", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"8", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "4"]}], 
          RowBox[{"Log", "[", "m3s", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["t1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"8", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], ")"}]}]}]}], 
       "]"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc00", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", 
     ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        FractionBox[
         RowBox[{"p12s", "+", "p1s", "+", "p2s"}], 
         RowBox[{"48", " ", "m3s"}]], ",", "\[IndentingNewLine]", "s12", ",", 
        
        RowBox[{
         FractionBox["1", 
          RowBox[{"72", " ", "m3s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "p12s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "-", 
                 RowBox[{"5", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}], "+", 
              RowBox[{"3", " ", "p2s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "-", 
                 RowBox[{"5", " ", "t1"}], "+", 
                 SuperscriptBox["t1", "2"]}], ")"}]}], "+", 
              RowBox[{"p1s", " ", 
               RowBox[{"(", 
                RowBox[{"11", "-", 
                 RowBox[{"7", " ", "t1"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"p1s", "-", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{"p12s", "+", "p2s"}], ")"}], " ", "t1"}]}], ")"}], 
            " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               RowBox[{"(", 
                RowBox[{"p1s", "+", "p2s"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"5", " ", "t2"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
              RowBox[{"p12s", " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", 
                 RowBox[{"7", " ", "t2"}], "+", 
                 RowBox[{"11", " ", 
                  SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["t2", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "p1s"}], "-", 
              RowBox[{"3", " ", "p2s"}], "+", 
              RowBox[{"p12s", " ", "t2"}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"72", " ", "m3s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"72", " ", "m3s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"p2s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", 
                 RowBox[{"7", " ", "t1"}], "-", 
                 RowBox[{"11", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", "p12s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"5", " ", "t1"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}], "+", 
              RowBox[{"3", " ", "p1s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"5", " ", "t1"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t1", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["t1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "p12s"}], "-", 
              RowBox[{"3", " ", "p1s"}], "+", 
              RowBox[{"p2s", " ", "t1"}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "us", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"p12s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["t1", "2"]}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", "t2"}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t2"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t1", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["t1", "3"]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "-", 
                    RowBox[{"2", " ", "t1", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"12", " ", "m3s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"p2s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
               RowBox[{"Log", "[", "t1", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "-", 
                    RowBox[{"t1", " ", "t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}], " ", 
                  RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"12", " ", "m3s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"p1s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["t1", "2"]}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", 
                 RowBox[{"3", " ", "t2"}], "+", 
                 RowBox[{"2", " ", "t1", " ", "t2"}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t1", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["t1", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
                    SuperscriptBox["t2", "3"], "-", 
                    RowBox[{"t1", " ", 
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}]}], ")"}], " ", 
                  RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"12", " ", "m3s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}]}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "]"}]}], ";"}]}], "Code",
 CellChangeTimes->{{3.564451186927245*^9, 3.5644511873195467`*^9}, {
  3.583470055787429*^9, 3.583470062395589*^9}, {3.583471087693371*^9, 
  3.583471087732086*^9}, {3.583533822988307*^9, 3.583533830583248*^9}, {
  3.5835417134780617`*^9, 3.5835417236079197`*^9}, {3.583561621672546*^9, 
  3.583561625428224*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc11", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], 
   ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"12", " ", "m3s"}]]}], ",", "\[IndentingNewLine]", "s12", 
        ",", 
        FractionBox[
         RowBox[{"11", "-", 
          RowBox[{"18", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", "+", 
           RowBox[{"3", " ", "t2"}], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["t2", "2"]}], "+", 
           SuperscriptBox["t2", "3"], "+", 
           RowBox[{"6", " ", "t2", " ", 
            RowBox[{"Log", "[", "t2", "]"}]}]}], 
          RowBox[{"6", " ", "m3s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"11", " ", 
           SuperscriptBox["t1", "3"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", "\[IndentingNewLine]", 
        RowBox[{
         FractionBox["1", "m3s"], 
         FractionBox["1", 
          RowBox[{"6", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", "t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"3", " ", "t2"}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
                 
                 SuperscriptBox["t2", "2"], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "-", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc11", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", 
     ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"48", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m2s"}], ")"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m3s"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m2s", "-", "m3s"}], ")"}], "4"]}]]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["m2s", "3"], " ", 
           SuperscriptBox["m3s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "2"], "-", 
             RowBox[{"4", " ", "m2s", " ", "m3s"}], "-", 
             RowBox[{"13", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
          RowBox[{"3", " ", "m1s", " ", 
           SuperscriptBox["m2s", "2"], " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["m2s", "3"]}], "-", 
             RowBox[{"7", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"22", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"37", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["m1s", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "3"], "-", 
             RowBox[{"5", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
             RowBox[{"13", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["m2s", "4"]}], "-", 
             RowBox[{"10", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "-", 
             RowBox[{"41", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"130", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "-", 
             RowBox[{"16", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              SuperscriptBox["m2s", "4"]}], "+", 
             RowBox[{"49", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"148", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"94", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", "p12s"}],
        "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["m2s", "3"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"22", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"31", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["m1s", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "3"], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"13", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "20"}], " ", 
                 SuperscriptBox["m2s", "4"]}], "+", 
                RowBox[{"59", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"42", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"233", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "-", 
                RowBox[{"26", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"11", " ", 
                 SuperscriptBox["m2s", "4"]}], "-", 
                RowBox[{"62", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"187", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"50", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}], "+", 
             RowBox[{"m1s", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["m2s", "4"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "-", 
                RowBox[{"73", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                RowBox[{"130", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "+", 
                RowBox[{"10", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", 
           "p1s"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["m2s", "3"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "2"], "-", 
                RowBox[{"8", " ", "m2s", " ", "m3s"}], "-", 
                RowBox[{"17", " ", 
                 SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "3"]}], "-", 
                RowBox[{"12", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"21", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                RowBox[{"44", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["m1s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "3"], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"13", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
             RowBox[{"m1s", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"21", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"49", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}]}], ")"}], " ", 
           "p2s"}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], "5"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m2s", "-", "m3s"}], ")"}], "5"]}]], "m2s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", 
           SuperscriptBox["m1s", "3"], " ", 
           SuperscriptBox["m3s", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["m2s", "3"], " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["m2s", "2"]}], "-", 
             RowBox[{"19", " ", "m2s", " ", "m3s"}], "-", 
             RowBox[{"7", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", "m1s", " ", 
           SuperscriptBox["m2s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "3"], "-", 
             RowBox[{"9", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
             RowBox[{"30", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"14", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["m2s", "3"]}], "-", 
             RowBox[{"25", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
             RowBox[{"50", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"42", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}]}], ")"}], " ", "p12s"}],
        "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SuperscriptBox["m1s", "4"], " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{
              SuperscriptBox["m2s", "4"], " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", " ", "m2s"}], "+", "m3s"}], ")"}]}], "+", 
             RowBox[{"m1s", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["m2s", "2"]}], "-", 
                RowBox[{"33", " ", "m2s", " ", "m3s"}], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", 
              SuperscriptBox["m2s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "3"]}], "-", 
                RowBox[{"27", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"60", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"10", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "4"], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"10", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"30", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "-", 
                RowBox[{"4", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", 
           "p1s"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["m1s", "3"], " ", 
              SuperscriptBox["m3s", "3"]}], "-", 
             RowBox[{
              SuperscriptBox["m2s", "3"], " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "m2s"}], "+", "m3s"}], ")"}]}], "-", 
             RowBox[{"2", " ", "m1s", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "2"], "-", 
                RowBox[{"5", " ", "m2s", " ", "m3s"}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["m3s", "2"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "3"], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"10", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}]}], ")"}], " ", 
           "p2s"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["m2s", "m1s"], "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m3s", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"24", " ", 
            SuperscriptBox["m1s", "2"], " ", "m2s"}], "+", 
           RowBox[{"m1s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["m2s", "2"]}], "-", 
              RowBox[{"47", " ", "m2s", " ", "m3s"}], "-", 
              RowBox[{"5", " ", 
               SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
           RowBox[{"m3s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", 
               SuperscriptBox["m2s", "2"]}], "+", 
              RowBox[{"19", " ", "m2s", " ", "m3s"}], "+", 
              RowBox[{"7", " ", 
               SuperscriptBox["m3s", "2"]}]}], ")"}]}]}], ")"}], " ", 
         "p12s"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m3s"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", "m1s", " ", "m2s"}], "-", 
              RowBox[{"m3s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"7", " ", "m2s"}], "+", "m3s"}], ")"}]}]}], ")"}], 
            " ", "p1s"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", "m1s", " ", "m2s"}], "+", 
              RowBox[{"m3s", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "m2s"}], "+", "m3s"}], ")"}]}]}], ")"}], 
            " ", "p2s"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox["m3s", "m1s"], "]"}]}], 
     RowBox[{"24", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1s", "-", "m3s"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "m2s"}], "+", "m3s"}], ")"}], "5"]}]]}]}], 
  ";"}]}], "Code",
 CellChangeTimes->{{3.564173297874382*^9, 3.564173307816777*^9}, {
   3.583470067071445*^9, 3.583470071729197*^9}, 3.5834710878113117`*^9, {
   3.583533833756057*^9, 3.583533842042808*^9}, {3.583541726654731*^9, 
   3.583541730712893*^9}, {3.5835417831105433`*^9, 3.583541828789001*^9}, {
   3.58354189847287*^9, 3.58354189883217*^9}, 3.583561628123493*^9, {
   3.604971878242309*^9, 3.6049719251077147`*^9}, 3.6049719925456553`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc12", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], 
   ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"24", " ", "m3s"}]]}], ",", "\[IndentingNewLine]", "s12", 
        ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", "+", 
           RowBox[{"3", " ", "t1"}], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["t1", "2"]}], "+", 
           SuperscriptBox["t1", "3"], "+", 
           RowBox[{"6", " ", "t1", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"12", " ", "m3s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t2"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"12", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"11", " ", 
           SuperscriptBox["t1", "3"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", "\[IndentingNewLine]", 
        RowBox[{
         FractionBox["1", "m3s"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["t1", "3"]}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "-", 
                  RowBox[{"t1", " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "+", 
                  RowBox[{"2", " ", "t2"}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}]}]}], 
       "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc12", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", 
     ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"48", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m2s", "-", "m3s"}], ")"}], "4"]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["m2s", "3"], " ", 
           SuperscriptBox["m3s", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "2"], "-", 
             RowBox[{"44", " ", "m2s", " ", "m3s"}], "-", 
             RowBox[{"5", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox["m1s", "5"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "3"], "-", 
             RowBox[{"7", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"7", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
          RowBox[{"m1s", " ", 
           SuperscriptBox["m2s", "2"], " ", 
           SuperscriptBox["m3s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["m2s", "3"]}], "+", 
             RowBox[{"113", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
             RowBox[{"113", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"15", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["m2s", "4"]}], "-", 
             RowBox[{"46", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "-", 
             RowBox[{"149", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"54", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "3"], " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"24", " ", 
              SuperscriptBox["m2s", "4"]}], "+", 
             RowBox[{"189", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
             RowBox[{"251", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"11", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["m1s", "2"], " ", "m2s", " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              SuperscriptBox["m2s", "4"]}], "+", 
             RowBox[{"67", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
             RowBox[{"307", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"85", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"15", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", "p12s"}],
        "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["m2s", "3"], " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "5"}], " ", 
                 SuperscriptBox["m2s", "2"]}], "-", 
                RowBox[{"44", " ", "m2s", " ", "m3s"}], "+", 
                SuperscriptBox["m3s", "2"]}], ")"}]}], "+", 
             RowBox[{"m1s", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"10", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"69", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"114", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["m1s", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "3"], "-", 
                RowBox[{"7", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"7", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "3"], " ", "m2s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "5"}], " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"58", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"121", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"18", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "4"]}], "+", 
                RowBox[{"16", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"193", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"68", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "+", 
                RowBox[{"6", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", 
           "p1s"}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["m2s", "3"]}], " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "2"], "+", 
                RowBox[{"10", " ", "m2s", " ", "m3s"}], "+", 
                SuperscriptBox["m3s", "2"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "3"], "-", 
                RowBox[{"7", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"7", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "3"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"10", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"35", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"2", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
             RowBox[{"m1s", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"17", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"26", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m2s", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["m2s", "4"], "+", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"44", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"19", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "+", 
                RowBox[{"3", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", 
           "p2s"}]}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m2s", "-", "m3s"}], ")"}], "5"]}]], 
     SuperscriptBox["m2s", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", 
           SuperscriptBox["m1s", "2"], " ", 
           SuperscriptBox["m3s", "2"]}], "+", 
          RowBox[{"3", " ", "m1s", " ", "m2s", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "2"], "-", 
             RowBox[{"5", " ", "m2s", " ", "m3s"}], "-", 
             RowBox[{"12", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m2s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["m2s", "2"]}], "+", 
             RowBox[{"11", " ", "m2s", " ", "m3s"}], "+", 
             RowBox[{"14", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}]}], ")"}], " ", "p12s"}],
        "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", 
           SuperscriptBox["m1s", "3"], " ", 
           SuperscriptBox["m3s", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["m2s", "2"], " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "14"}], " ", 
              SuperscriptBox["m2s", "2"]}], "-", 
             RowBox[{"11", " ", "m2s", " ", "m3s"}], "+", 
             SuperscriptBox["m3s", "2"]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["m1s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "3"], "-", 
             RowBox[{"5", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"22", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
          RowBox[{"m1s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "6"}], " ", 
              SuperscriptBox["m2s", "4"]}], "+", 
             RowBox[{"38", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
             RowBox[{"44", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"4", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}]}], ")"}], " ", "p1s"}], 
       "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox["m1s", "2"], " ", 
           SuperscriptBox["m3s", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["m2s", "2"], " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{"m2s", "+", "m3s"}], ")"}]}], "+", 
          RowBox[{"m1s", " ", "m2s", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "2"], "-", 
             RowBox[{"5", " ", "m2s", " ", "m3s"}], "-", 
             RowBox[{"8", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}]}], ")"}], " ", 
        "p2s"}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["m2s", "m1s"], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "m2s"}], "+", "m3s"}], ")"}], "5"]}]], 
     SuperscriptBox["m3s", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"24", " ", 
           SuperscriptBox["m1s", "3"], " ", 
           SuperscriptBox["m2s", "2"]}], "+", 
          RowBox[{"m2s", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["m2s", "2"], "-", 
             RowBox[{"11", " ", "m2s", " ", "m3s"}], "-", 
             RowBox[{"14", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["m1s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["m2s", "3"]}], "-", 
             RowBox[{"22", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"5", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
          RowBox[{"m1s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
             RowBox[{"44", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"38", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "-", 
             RowBox[{"6", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", "p12s"}],
        "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"24", " ", 
              SuperscriptBox["m1s", "2"], " ", 
              SuperscriptBox["m2s", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"14", " ", 
                 SuperscriptBox["m2s", "2"]}], "+", 
                RowBox[{"11", " ", "m2s", " ", "m3s"}], "-", 
                SuperscriptBox["m3s", "2"]}], ")"}]}], "+", 
             RowBox[{"3", " ", "m1s", " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "12"}], " ", 
                 SuperscriptBox["m2s", "2"]}], "-", 
                RowBox[{"5", " ", "m2s", " ", "m3s"}], "+", 
                SuperscriptBox["m3s", "2"]}], ")"}]}]}], ")"}], " ", "p1s"}], 
          "-", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              SuperscriptBox["m1s", "2"], " ", 
              SuperscriptBox["m2s", "2"]}], "+", 
             RowBox[{"3", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"m2s", "+", "m3s"}], ")"}]}], "+", 
             RowBox[{"m1s", " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "8"}], " ", 
                 SuperscriptBox["m2s", "2"]}], "-", 
                RowBox[{"5", " ", "m2s", " ", "m3s"}], "+", 
                SuperscriptBox["m3s", "2"]}], ")"}]}]}], ")"}], " ", 
           "p2s"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["m3s", "m1s"], "]"}]}]}]}], ";"}]}], "Code",
 CellChangeTimes->{{3.5641733160410347`*^9, 3.564173326620097*^9}, {
   3.5834700841666727`*^9, 3.5834700888564453`*^9}, 3.583471087914106*^9, {
   3.5835338453728867`*^9, 3.58353384822445*^9}, {3.58354173476324*^9, 
   3.5835417513610077`*^9}, {3.583541835024803*^9, 3.5835418865744877`*^9}, 
   3.583561631467924*^9, {3.604971965040657*^9, 3.604971985625731*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CFant", "[", 
    RowBox[{"LoopTools`cc22", ",", "m1s_", ",", "m2s_", ",", "m3s_"}], "]"}], 
   ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "s123", ",", "s12", ",", "s13", ",", "s23", ",", 
       "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"t1", "=", 
       FractionBox["m1s", "m3s"]}], ";", 
      RowBox[{"t2", "=", 
       FractionBox["m2s", "m3s"]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s123", ",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"12", " ", "m3s"}]]}], ",", "\[IndentingNewLine]", "s12", 
        ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"6", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "t2"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          RowBox[{"11", " ", 
           SuperscriptBox["t2", "3"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["t2", "3"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"18", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"11", " ", 
           SuperscriptBox["t1", "3"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", "m3s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "us", ",", "\[IndentingNewLine]", 
        RowBox[{
         FractionBox["1", "m3s"], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["t1", "3"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"5", " ", "t2"}]}], ")"}]}], "+", "t2", "-", 
                  RowBox[{"3", " ", 
                   SuperscriptBox["t2", "2"]}], "+", 
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t2", "3"], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"6", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}]}]}], 
       "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "LoopTools`cc22", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", 
     ",", "m2s_", ",", "m3s_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"48", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m2s"}], ")"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m3s"}], ")"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m2s", "-", "m3s"}], ")"}], "4"]}]]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["m1s", "5"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["m2s", "3"]}], "+", 
             RowBox[{"13", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"5", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m2s", "2"], " ", 
           SuperscriptBox["m3s", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["m2s", "3"]}], "-", 
             RowBox[{"31", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"22", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "-", 
          RowBox[{"2", " ", "m1s", " ", "m2s", " ", 
           SuperscriptBox["m3s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["m2s", "4"]}], "-", 
             RowBox[{"64", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "-", 
             RowBox[{"52", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"12", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["m1s", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"18", " ", 
              SuperscriptBox["m2s", "4"]}], "+", 
             RowBox[{"102", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
             RowBox[{"167", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"58", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"11", " ", 
              SuperscriptBox["m3s", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", 
              SuperscriptBox["m2s", "5"]}], "+", 
             RowBox[{"24", " ", 
              SuperscriptBox["m2s", "4"], " ", "m3s"}], "+", 
             RowBox[{"420", " ", 
              SuperscriptBox["m2s", "3"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"20", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"70", " ", "m2s", " ", 
              SuperscriptBox["m3s", "4"]}], "-", 
             RowBox[{"20", " ", 
              SuperscriptBox["m3s", "5"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "2"], " ", "m3s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"26", " ", 
              SuperscriptBox["m2s", "5"]}], "-", 
             RowBox[{"223", " ", 
              SuperscriptBox["m2s", "4"], " ", "m3s"}], "-", 
             RowBox[{"172", " ", 
              SuperscriptBox["m2s", "3"], " ", 
              SuperscriptBox["m3s", "2"]}], "-", 
             RowBox[{"132", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "3"]}], "+", 
             RowBox[{"18", " ", "m2s", " ", 
              SuperscriptBox["m3s", "4"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["m3s", "5"]}]}], ")"}]}]}], ")"}], " ", "p12s"}],
        "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"13", " ", 
                 SuperscriptBox["m2s", "2"]}], "+", 
                RowBox[{"4", " ", "m2s", " ", "m3s"}], "-", 
                SuperscriptBox["m3s", "2"]}], ")"}]}], "-", 
             RowBox[{"3", " ", "m1s", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"37", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"22", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"7", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["m1s", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"13", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"5", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"16", " ", 
                 SuperscriptBox["m2s", "4"]}], "+", 
                RowBox[{"130", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"41", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"10", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"94", " ", 
                 SuperscriptBox["m2s", "4"]}], "+", 
                RowBox[{"148", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"49", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                RowBox[{"3", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}]}], ")"}], " ", 
           "p1s"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "17"}], " ", 
                 SuperscriptBox["m2s", "2"]}], "-", 
                RowBox[{"8", " ", "m2s", " ", "m3s"}], "+", 
                SuperscriptBox["m3s", "2"]}], ")"}]}], "+", 
             RowBox[{"m1s", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"49", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"38", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
                RowBox[{"11", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["m1s", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"13", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"5", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["m2s", "4"]}], "+", 
                RowBox[{"70", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "+", 
                RowBox[{"11", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"14", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "-", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m3s", "4"]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "44"}], " ", 
                 SuperscriptBox["m2s", "4"]}], "-", 
                RowBox[{"70", " ", 
                 SuperscriptBox["m2s", "3"], " ", "m3s"}], "-", 
                RowBox[{"33", " ", 
                 SuperscriptBox["m2s", "2"], " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"2", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "3"]}], "+", 
                SuperscriptBox["m3s", "4"]}], ")"}]}]}], ")"}], " ", 
           "p2s"}]}], ")"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["m2s", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["m2s", "2"]}], "+", 
           RowBox[{"8", " ", "m1s", " ", "m3s"}], "-", 
           RowBox[{"7", " ", "m2s", " ", "m3s"}]}], ")"}], " ", "p12s"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "5"}], " ", "m1s", " ", 
            SuperscriptBox["m2s", "2"]}], "+", 
           RowBox[{"7", " ", 
            SuperscriptBox["m2s", "3"]}], "+", 
           RowBox[{"24", " ", 
            SuperscriptBox["m1s", "2"], " ", "m3s"}], "-", 
           RowBox[{"47", " ", "m1s", " ", "m2s", " ", "m3s"}], "+", 
           RowBox[{"19", " ", 
            SuperscriptBox["m2s", "2"], " ", "m3s"}], "+", 
           RowBox[{"4", " ", "m1s", " ", 
            SuperscriptBox["m3s", "2"]}], "-", 
           RowBox[{"2", " ", "m2s", " ", 
            SuperscriptBox["m3s", "2"]}]}], ")"}], " ", "p1s"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"m1s", "-", "m2s"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["m2s", "2"]}], "+", 
           RowBox[{"4", " ", "m1s", " ", "m3s"}], "-", 
           RowBox[{"3", " ", "m2s", " ", "m3s"}]}], ")"}], " ", "p2s"}]}], 
       ")"}], " ", 
      RowBox[{"Log", "[", 
       FractionBox["m2s", "m1s"], "]"}]}], 
     RowBox[{"24", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m1s", "-", "m2s"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m2s", "-", "m3s"}], ")"}], "5"]}]], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"24", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], "5"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "m2s"}], "+", "m3s"}], ")"}], "5"]}]], "m3s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SuperscriptBox["m1s", "4"], " ", 
           SuperscriptBox["m2s", "3"]}], "+", 
          RowBox[{
           SuperscriptBox["m2s", "2"], " ", 
           SuperscriptBox["m3s", "4"], " ", 
           RowBox[{"(", 
            RowBox[{"m2s", "+", 
             RowBox[{"7", " ", "m3s"}]}], ")"}]}], "+", 
          RowBox[{"m1s", " ", "m2s", " ", 
           SuperscriptBox["m3s", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", 
              SuperscriptBox["m2s", "2"]}], "-", 
             RowBox[{"33", " ", "m2s", " ", "m3s"}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "2"], " ", 
           SuperscriptBox["m3s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"10", " ", 
              SuperscriptBox["m2s", "3"]}], "+", 
             RowBox[{"60", " ", 
              SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
             RowBox[{"27", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["m3s", "3"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["m1s", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["m2s", "4"]}], "-", 
             RowBox[{"30", " ", 
              SuperscriptBox["m2s", "3"], " ", "m3s"}], "-", 
             RowBox[{"10", " ", 
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "2"]}], "+", 
             RowBox[{"5", " ", "m2s", " ", 
              SuperscriptBox["m3s", "3"]}], "-", 
             SuperscriptBox["m3s", "4"]}], ")"}]}]}], ")"}], " ", "p12s"}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m1s", "-", "m3s"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"24", " ", 
              SuperscriptBox["m1s", "3"], " ", 
              SuperscriptBox["m2s", "3"]}], "+", 
             RowBox[{"m2s", " ", 
              SuperscriptBox["m3s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "7"}], " ", 
                 SuperscriptBox["m2s", "2"]}], "-", 
                RowBox[{"19", " ", "m2s", " ", "m3s"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["m3s", "2"]}]}], ")"}]}], "+", 
             RowBox[{"2", " ", "m1s", " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"14", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"30", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"9", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}], "-", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"42", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"50", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"25", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                RowBox[{"5", " ", 
                 SuperscriptBox["m3s", "3"]}]}], ")"}]}]}], ")"}], " ", 
           "p1s"}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "4"}], " ", 
              SuperscriptBox["m1s", "3"], " ", 
              SuperscriptBox["m2s", "3"]}], "+", 
             RowBox[{
              SuperscriptBox["m2s", "2"], " ", 
              SuperscriptBox["m3s", "3"], " ", 
              RowBox[{"(", 
               RowBox[{"m2s", "+", 
                RowBox[{"3", " ", "m3s"}]}], ")"}]}], "-", 
             RowBox[{"2", " ", "m1s", " ", "m2s", " ", 
              SuperscriptBox["m3s", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["m2s", "2"]}], "+", 
                RowBox[{"5", " ", "m2s", " ", "m3s"}], "-", 
                SuperscriptBox["m3s", "2"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["m1s", "2"], " ", "m3s", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 SuperscriptBox["m2s", "3"]}], "+", 
                RowBox[{"10", " ", 
                 SuperscriptBox["m2s", "2"], " ", "m3s"}], "-", 
                RowBox[{"5", " ", "m2s", " ", 
                 SuperscriptBox["m3s", "2"]}], "+", 
                SuperscriptBox["m3s", "3"]}], ")"}]}]}], ")"}], " ", 
           "p2s"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", 
      FractionBox["m3s", "m1s"], "]"}]}]}]}], ";"}]}], "Code",
 CellChangeTimes->{{3.5641733362537394`*^9, 3.564173336529108*^9}, {
   3.583470095712241*^9, 3.583470100511022*^9}, 3.583471087995871*^9, {
   3.583533851231131*^9, 3.583533854568367*^9}, {3.583541754202939*^9, 
   3.583541758472692*^9}, {3.583545640244997*^9, 3.583545640448114*^9}, 
   3.58356163489789*^9, {3.6049720214190407`*^9, 3.604972038679594*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CFDant", "[", 
    RowBox[{
    "id_", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", ",", "m2s_", 
     ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Derivative for C0i[\>\"", ",", "id", ",", 
        "\"\<] not implemented\>\""}], "]"}], ";", "\n", 
      RowBox[{
       RowBox[{"C0i", "[", 
        RowBox[{
        "id", ",", "p1s", ",", "p2s", ",", "p12s", ",", "m1s", ",", "m2s", 
         ",", "m3s"}], "]"}], "-", 
       RowBox[{"CFant", "[", 
        RowBox[{"id", ",", "m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}]}], 
    "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.583469986497876*^9, 3.583470024057682*^9}, {
   3.5834701319915943`*^9, 3.583470204853478*^9}, {3.583470235436049*^9, 
   3.583470244089932*^9}, {3.583470301058148*^9, 3.583470386478262*^9}, {
   3.583470481575275*^9, 3.583470516185871*^9}, {3.5834707942597427`*^9, 
   3.583470890048451*^9}, {3.583470979839161*^9, 3.583471022834826*^9}, {
   3.5834711094994707`*^9, 3.583471109889461*^9}, 3.583471774018762*^9, {
   3.583472328881145*^9, 3.583472396577066*^9}, {3.583472470021042*^9, 
   3.583472494696684*^9}, {3.5835338580567503`*^9, 3.583533863870874*^9}, {
   3.5835409743679733`*^9, 3.583541042103875*^9}, {3.583541764089794*^9, 
   3.5835417753359833`*^9}, {3.583541889912676*^9, 3.583541892497274*^9}, {
   3.604972055117565*^9, 3.604972085388516*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["D", "Subsection",
 CellChangeTimes->{{3.5835336627484703`*^9, 3.583533690372583*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd0", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["t1", "2"], "-", "t3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t3", " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}], ",", "s13", 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["t1", "2"], "-", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t2"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t2", "-", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3", " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t1"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "t1"}], "+", 
                 SuperscriptBox["t2", "2"]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t1"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t3", " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t1"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{"2", "-", 
          RowBox[{"2", " ", "t1"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{"2", "-", 
          RowBox[{"2", " ", "t1"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{"2", "-", 
          RowBox[{"2", " ", "t2"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["t1", "2"], "-", 
          RowBox[{"2", " ", "t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", "t1"}]], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["t3", "2"], "-", 
          RowBox[{"2", " ", "t3", " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["t2", "2"], "-", 
          RowBox[{"2", " ", "t2", " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox["t1", "2"], "-", 
          RowBox[{"2", " ", "t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"6", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t1"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"t2", " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3", " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.564173414969857*^9, 3.583471088078429*^9, {3.58347182081028*^9, 
   3.583471828927198*^9}, {3.5834724047472343`*^9, 3.583472405551409*^9}, {
   3.583533871680105*^9, 3.583533878103763*^9}, {3.58354197653405*^9, 
   3.583541980434699*^9}, {3.583542131928895*^9, 3.5835421420500174`*^9}, {
   3.583560086449458*^9, 3.583560088022689*^9}, 3.583561644241024*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd1", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["t1", "2"], " ", "t3"}], "+", 
              SuperscriptBox["t3", "2"], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "2"], "+", 
                 SuperscriptBox["t1", "3"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t3", "2"]}], "-", 
                 RowBox[{"t1", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"4", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t1", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"2", " ", "t2"}], "+", 
               RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], "-", 
                  RowBox[{"2", " ", "t1", " ", 
                   SuperscriptBox["t2", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"t2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}]}], "-", 
                  SuperscriptBox["t2", "2"], "+", 
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "/", 
         
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "t2"}], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "+", 
              SuperscriptBox["t2", "2"], "-", 
              RowBox[{"2", " ", "t3"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t2", "2"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}], " ", "t3"}], "+", 
                 
                 SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t1", "2"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "-", 
                 RowBox[{"4", " ", "t1", " ", "t2"}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "2"], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 SuperscriptBox["t2", "3"]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"3", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{"3", " ", "t1", " ", 
                  SuperscriptBox["t3", "2"]}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["t1", "2"]}], "-", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{"5", "-", 
          RowBox[{"4", " ", "t1"}], "-", 
          SuperscriptBox["t1", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"4", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t1"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t1", "2"]}], "+", 
           RowBox[{"2", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t1"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t1", "2"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "-", 
                 RowBox[{"4", " ", "t1", " ", "t2"}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "2"], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 SuperscriptBox["t2", "3"]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", "+", 
           FractionBox["2", "t1"], "-", 
           RowBox[{"6", " ", "t1"}], "+", 
           SuperscriptBox["t1", "2"], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t3"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t3", "2"], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t2"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t2", "2"]}], "+", 
           RowBox[{"2", " ", "t2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t2"}], ")"}], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", "s1234", 
        ",", 
        FractionBox[
         RowBox[{"-", "1"}], 
         RowBox[{"24", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["t2", "2"]}], "+", "t3"}], ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", 
                    RowBox[{"2", " ", "t3"}], "+", 
                    RowBox[{"t2", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["t2", "3"], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"t2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.583471088168283*^9, {3.583471835696607*^9, 3.583471840650495*^9}, {
   3.5835338833964357`*^9, 3.583533888411379*^9}, {3.583541984014296*^9, 
   3.583541998037105*^9}, 3.583561647276679*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd2", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s12", ",", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t1", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"2", " ", "t3"}], "+", 
               RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["t3", "2"], "-", 
                  RowBox[{"2", " ", "t1", " ", 
                   SuperscriptBox["t3", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"t3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t3"}], ")"}]}], "-", 
                  SuperscriptBox["t3", "2"], "+", 
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "-", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["m4s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}]}], ",",
         "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
              SuperscriptBox["t2", "2"], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "2"], "+", 
                 SuperscriptBox["t1", "3"], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t2", "2"]}], "-", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"4", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t2", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["t3", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}], "-", 
                 RowBox[{"t2", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"t3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["t2", "2"]}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t1", "2"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "-", 
                 RowBox[{"4", " ", "t1", " ", "t2"}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "2"], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 SuperscriptBox["t2", "3"]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["t3", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"t3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["t1", "2"]}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "2"]}], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t1", "+", "t2", "-", 
                 RowBox[{"3", " ", "t1", " ", "t2"}]}], ")"}]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t1"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t1", "2"]}], "+", 
           RowBox[{"2", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t1"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{"5", "-", 
          RowBox[{"4", " ", "t1"}], "-", 
          SuperscriptBox["t1", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"4", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{"5", "-", 
          RowBox[{"4", " ", "t2"}], "-", 
          SuperscriptBox["t2", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"4", " ", "t2"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", "+", 
           FractionBox["2", "t1"], "-", 
           RowBox[{"6", " ", "t1"}], "+", 
           SuperscriptBox["t1", "2"], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t3"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t3", "2"]}], "+", 
           RowBox[{"2", " ", "t3", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t3"}], ")"}], " ", 
            RowBox[{"Log", "[", "t3", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t2"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"24", " ", 
           SuperscriptBox["m4s", "2"]}]]}], ",", "\[IndentingNewLine]", "us", 
        ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["t1", "2"]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["t2", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"t2", "-", "t3"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t3"}], ")"}]}], "+", "t3"}], 
                    ")"}]}], "+", 
                    RowBox[{"t3", " ", 
                    RowBox[{"(", 
                    RowBox[{"t2", "-", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}], " ", 
                   RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.583471088244223*^9, {3.5834718453545303`*^9, 3.583471849131957*^9}, {
   3.583533892391225*^9, 3.5835338950346537`*^9}, {3.583541991035345*^9, 
   3.583541994881599*^9}, 3.58356165045944*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd3", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", 
       RowBox[{"s12", ",", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t1", " ", 
             RowBox[{"(", 
              RowBox[{"t1", "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"2", " ", "t3"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["t1", "2"]}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t3"}], ")"}]}], "+", 
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}], " ", "t3"}], "+", 
                  
                  SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t3", "2"], " ", 
                RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["m4s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}]}], ",",
         "\[IndentingNewLine]", "s13", ",", 
        RowBox[{"-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t1", " ", 
             RowBox[{"(", 
              RowBox[{"t1", "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"2", " ", "t2"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["t1", "2"]}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}]}], "+", 
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
                  
                  SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", 
            SuperscriptBox["m4s", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}]}], ",",
         "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t3"}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "t2"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", "t2"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", 
                  SuperscriptBox["t1", "2"]}], "-", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"3", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{"3", " ", "t1", " ", 
                  SuperscriptBox["t3", "2"]}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "-", "t2", "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"3", " ", "t2"}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t1"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t1", "2"]}], "+", 
           RowBox[{"2", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t1"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t1"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t1", "2"]}], "+", 
           RowBox[{"2", " ", "t1", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t1"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "+", 
           RowBox[{"4", " ", "t2"}], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox["t2", "2"]}], "+", 
           RowBox[{"2", " ", "t2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", "t2"}], ")"}], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}]}], 
          RowBox[{"4", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}]]}], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        FractionBox[
         RowBox[{"5", "-", 
          RowBox[{"4", " ", "t1"}], "-", 
          SuperscriptBox["t1", "2"], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"4", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t3"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t3", "2"], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"24", " ", 
           SuperscriptBox["m4s", "2"]}]]}], ",", "\[IndentingNewLine]", "us", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t1", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t3"}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "t2"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{
  3.583471088328828*^9, {3.5834718559193897`*^9, 3.5834718604266033`*^9}, {
   3.5835338991739693`*^9, 3.583533901915449*^9}, {3.583542002304347*^9, 
   3.583542021043969*^9}, 3.583561653270439*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd00", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "t1"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"t1", "-", 
               RowBox[{"2", " ", "t3"}], "+", 
               RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"t1", " ", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                SuperscriptBox["t3", "2"], " ", 
                RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "m4s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "t1"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"t1", "-", 
               RowBox[{"2", " ", "t2"}], "+", 
               RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"t1", " ", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "m4s", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], ")"}]}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t2", "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t2", "-", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", "m4s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", "t2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t2"}], ")"}]}], "+", "t2"}], 
                ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", "m4s", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", "m4s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "2"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"4", " ", "m4s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox["t1", "2"], "+", 
          RowBox[{"2", " ", "t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", " ", "m4s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox["t1", "2"], "+", 
          RowBox[{"2", " ", "t1", " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"4", " ", "m4s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          SuperscriptBox["t2", "2"], "+", 
          RowBox[{"2", " ", "t2", " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"4", " ", "m4s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"3", "-", 
           RowBox[{"4", " ", "t1"}], "+", 
           SuperscriptBox["t1", "2"], "+", 
           RowBox[{"2", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"8", " ", "m4s", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]]}], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "t3"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t3", "2"], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"8", " ", "m4s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "t2"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"8", " ", "m4s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "t1"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"8", " ", "m4s", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"12", " ", "m4s"}]]}], ",", "\[IndentingNewLine]", "us", 
        ",", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["t1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                SuperscriptBox["t3", "2"], " ", 
                RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "m4s", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}]}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.565959762015066*^9, 3.565959809250531*^9}, 
   3.583471088427826*^9, {3.583471864502432*^9, 3.5834718690584927`*^9}, {
   3.583533905582265*^9, 3.583533908444522*^9}, {3.583542009581064*^9, 
   3.5835420162365513`*^9}, 3.583561656172773*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd11", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               SuperscriptBox["t1", "2"], " ", 
               SuperscriptBox["t3", "2"]}], "-", 
              SuperscriptBox["t3", "3"], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox["t1", "3"], " ", "t3", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "4"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t3", "+", 
                 SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "5"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
              RowBox[{"11", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               SuperscriptBox["t3", "3"]}], "+", 
              RowBox[{"t1", " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"18", "-", 
                 RowBox[{"11", " ", "t3"}], "-", 
                 RowBox[{"7", " ", 
                  SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "4"], " ", 
               RowBox[{"(", 
                RowBox[{"5", "+", "t3", "-", 
                 RowBox[{"6", " ", 
                  SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "2"], " ", "t3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "9"}], "+", 
                 RowBox[{"12", " ", "t3"}], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["t3", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t3", "3"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", 
                 RowBox[{"17", " ", "t3"}], "+", 
                 RowBox[{"12", " ", 
                  SuperscriptBox["t3", "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t3", "3"]}]}], ")"}]}], "-", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["t1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t2"}], "+", 
               RowBox[{"2", " ", "t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t2", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"7", " ", "t2"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", "t2", "-", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "-", 
                    RowBox[{"9", " ", "t2"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", "t2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "t1"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "t2"}], ")"}], " ", 
                   SuperscriptBox["t2", "2"]}], "-", 
                  SuperscriptBox["t2", "3"], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"3", " ", "t2"}], "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "/", 
         
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "t2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"4", " ", "t3"}]}], ")"}]}], "-", 
              RowBox[{"3", " ", "t2", " ", "t3"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["t3", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", "t3"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"3", " ", "t3"}]}], ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["t2", "4"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "-", 
                    RowBox[{"5", " ", "t3"}]}], ")"}], " ", 
                  SuperscriptBox["t3", "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t3", "3"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "14"}], "+", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1", " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "6"}], "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "3"], "-", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "3"]}], "-", 
                 SuperscriptBox["t2", "4"], "-", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"6", "-", 
                    RowBox[{"4", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"7", " ", "t3"}], "-", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"12", " ", "t3"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "+", "t2"}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "+", 
                    RowBox[{"7", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"14", "+", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", "t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "3"]}], "-", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "-", 
                    RowBox[{"3", " ", "t2"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    SuperscriptBox["t2", "3"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t2"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          SuperscriptBox["t2", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t2"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", "+", 
           FractionBox["3", 
            RowBox[{"2", " ", "t1"}]], "-", 
           RowBox[{"9", " ", "t1"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["t1", "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t1", "3"], "2"], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]]}], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t3"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t3", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t3", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t3", "3"], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t2"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          SuperscriptBox["t2", "3"], "-", 
          RowBox[{"6", " ", "t2", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"6", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"60", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["t2", "4"], "-", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["t2", "2"], " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["t2", "3"], " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["t3", "3"]}], "-", 
                    RowBox[{"t2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", 
                    SuperscriptBox["t2", "2"], " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["t2", "3"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["t2", "5"], "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["t2", "3"], " ", "t3"}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["t3", "3"]}], "+", 
                    RowBox[{"3", " ", "t2", " ", 
                    SuperscriptBox["t3", "3"]}], "-", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    SuperscriptBox["t3", "3"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["t2", "4"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"3", " ", "t2", " ", "t3", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}]}], ")"}], 
               " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "t2"}], " ", "t3", " ", 
                    RowBox[{"(", 
                    RowBox[{"t2", "+", 
                    SuperscriptBox["t2", "2"], "-", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    RowBox[{"t2", " ", "t3"}]}], ")"}]}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], "+", 
                    SuperscriptBox["t2", "3"], "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"3", " ", "t2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], "+", 
                    RowBox[{"5", " ", "t3"}], "-", 
                    RowBox[{"3", " ", "t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}]}]}], ")"}]}], 
                 "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
                  SuperscriptBox["t3", "3"], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], ")"}]}]}], "]"}]}]}], 
    "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.564173549271865*^9, 3.5641735671629133`*^9}, 
   3.583471088526825*^9, {3.583471875875708*^9, 3.5834718767166767`*^9}, {
   3.583472138102755*^9, 3.583472138392456*^9}, {3.583533912894279*^9, 
   3.5835339158413563`*^9}, {3.583542029129941*^9, 3.583542034037562*^9}, 
   3.583561659225275*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd12", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "t1", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "t3"}], ")"}], " ", "t3"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["t3", "2"]}], "-", 
              RowBox[{"3", " ", "t1", " ", 
               SuperscriptBox["t3", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"2", " ", "t3"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t1", "4"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"3", " ", "t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"3", " ", "t3"}]}], ")"}], " ", 
                  SuperscriptBox["t3", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t3", "3"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3", "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t3", "2"], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "t1", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["t2", "2"]}], "-", 
              RowBox[{"3", " ", "t1", " ", 
               SuperscriptBox["t2", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"2", " ", "t2"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t1", "4"]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
                 RowBox[{"3", " ", "t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"3", " ", "t2"}]}], ")"}], " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "3"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2", "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "6"}], "+", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t2", "2"], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["t2", "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "+", 
              SuperscriptBox["t2", "2"], "-", 
              RowBox[{"3", " ", "t3"}], "+", 
              RowBox[{"t2", " ", "t3"}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["t3", "3"]}], "+", 
                 RowBox[{"t2", " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t3"}], ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1", " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "6"}], "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "3"], "-", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "3"]}], "-", 
                 SuperscriptBox["t2", "4"], "-", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"6", "-", 
                    RowBox[{"4", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"36", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"5", " ", "t3"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3", "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1"}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t3"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "3"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t2"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "3"}], " ", "t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "-", 
          RowBox[{"6", " ", "t1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "-", 
          RowBox[{"6", " ", "t1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t2"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          SuperscriptBox["t2", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t2"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", "+", 
           FractionBox["3", 
            RowBox[{"2", " ", "t1"}]], "-", 
           RowBox[{"9", " ", "t1"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["t1", "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t1", "3"], "2"], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"36", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]]}], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t3"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t3", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t3"}], ")"}], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t2"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"72", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"120", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "3"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t2", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["t2", "2"], "-", 
                    RowBox[{"2", " ", "t3"}], "+", 
                    RowBox[{"t2", " ", "t3"}]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    RowBox[{"2", " ", "t2", " ", "t3"}]}], ")"}]}]}], ")"}], 
               " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"t2", " ", "t3", " ", 
                    RowBox[{"(", 
                    RowBox[{"t2", "+", "t3", "-", 
                    RowBox[{"2", " ", "t2", " ", "t3"}]}], ")"}]}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "-", 
                    SuperscriptBox["t3", "2"], "+", 
                    RowBox[{"t2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"t2", " ", "t3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t3"}], ")"}]}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"t3", "+", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}]}], ")"}]}], "-", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", "t3"}], "+", 
                    
                    SuperscriptBox["t3", "3"], "+", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}]}], ")"}]}]}], ")"}], 
                  " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.564173576881318*^9, 3.564173592483755*^9}, 
   3.583471088613267*^9, {3.5834718817053633`*^9, 3.583471886737471*^9}, {
   3.583533919422235*^9, 3.583533922222386*^9}, {3.583542037802154*^9, 
   3.583542042078621*^9}, 3.583561662695838*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd13", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "t1", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"4", " ", "t3"}]}], ")"}]}], "-", 
              RowBox[{"3", " ", "t1", " ", "t3"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["t3", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", "t3"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"3", " ", "t3"}]}], ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["t1", "4"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "-", 
                    RowBox[{"5", " ", "t3"}]}], ")"}], " ", 
                  SuperscriptBox["t3", "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t3", "3"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "14"}], "+", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["t1", "2"]}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t1", "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t2"}], "+", 
               RowBox[{"t1", " ", "t2"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t2", "3"]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t2", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "t2"}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t2", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t2"}], ")"}]}], "+", 
                  RowBox[{"t2", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t2"}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}]}], "/", 
         
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t2", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t2"}], "+", 
              SuperscriptBox["t2", "2"], "-", 
              RowBox[{"3", " ", "t3"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t2", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t3", "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"9", " ", "t3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "+", "t2"}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "+", 
                    RowBox[{"7", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"14", "+", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", "t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "3"]}], "-", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "-", 
                    RowBox[{"3", " ", "t2"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    SuperscriptBox["t2", "3"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"7", " ", "t3"}], "-", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"12", " ", "t3"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"36", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"5", " ", "t2"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2", "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1"}], "-", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t2"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "-", 
          RowBox[{"6", " ", "t1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t2"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          SuperscriptBox["t2", "3"], "-", 
          RowBox[{"6", " ", "t2", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t3"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t3", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t3", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t3", "3"], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"72", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t2"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"72", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"120", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "3"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}]}], " ", 
               SuperscriptBox["t2", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "+", 
                    SuperscriptBox["t2", "2"], "-", 
                    RowBox[{"2", " ", "t3"}]}], ")"}], " ", "t3"}], "-", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["t2", "2"], "+", 
                    SuperscriptBox["t2", "3"], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"t2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", "t3"}], "+", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"2", "+", "t3"}], ")"}]}]}], ")"}]}]}], ")"}], 
               " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "t2"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "t3"}], ")"}]}], "+", "t3"}], 
                    ")"}]}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "t2"}], "+", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], "+", "t3"}], 
                    ")"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t2"}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
                  SuperscriptBox["t3", "3"], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "2"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.5641736105584593`*^9, 3.564173624363183*^9}, 
   3.583471088700059*^9, {3.5834718918604603`*^9, 3.583471894893556*^9}, {
   3.5835339262625523`*^9, 3.583533934028646*^9}, {3.58354204595679*^9, 
   3.58354204967981*^9}, {3.583544440205599*^9, 3.5835444465115347`*^9}, 
   3.5835616672593393`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd22", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["t1", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t3"}], "+", 
               RowBox[{"2", " ", "t1", " ", "t3"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["t3", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t3", " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "+", 
                    RowBox[{"7", " ", "t3"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t3", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], "+", "t3", "-", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "-", 
                    RowBox[{"9", " ", "t3"}], "+", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{"2", " ", "t3", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "t1"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "t3"}], ")"}], " ", 
                   SuperscriptBox["t3", "2"]}], "-", 
                  SuperscriptBox["t3", "3"], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"3", " ", "t3"}], "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}], "/", 
         
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"6", " ", 
               SuperscriptBox["t1", "2"], " ", 
               SuperscriptBox["t2", "2"]}], "-", 
              SuperscriptBox["t2", "3"], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox["t1", "3"], " ", "t2", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "4"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "t2", "+", 
                 SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "5"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
              RowBox[{"11", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               SuperscriptBox["t2", "3"]}], "+", 
              RowBox[{"t1", " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"18", "-", 
                 RowBox[{"11", " ", "t2"}], "-", 
                 RowBox[{"7", " ", 
                  SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "4"], " ", 
               RowBox[{"(", 
                RowBox[{"5", "+", "t2", "-", 
                 RowBox[{"6", " ", 
                  SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "2"], " ", "t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "9"}], "+", 
                 RowBox[{"12", " ", "t2"}], "-", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "3"]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "-", 
                 RowBox[{"17", " ", "t2"}], "+", 
                 RowBox[{"12", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t2", "3"]}]}], ")"}]}], "-", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t2", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "+", "t3"}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "+", 
                    RowBox[{"7", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "-", 
                 RowBox[{"t2", " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"14", "+", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", "t3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["t2", "3"]}], "-", 
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{"t2", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "-", 
                    RowBox[{"3", " ", "t3"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    SuperscriptBox["t3", "3"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1", " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "6"}], "-", "t2", "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["t1", "3"], "-", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t2", "3"]}], "-", 
                 SuperscriptBox["t2", "4"], "-", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"6", "-", 
                    RowBox[{"4", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "+", "t3"}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "+", 
                    RowBox[{"7", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"14", "+", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", "t3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "3"]}], "-", 
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "-", 
                    RowBox[{"3", " ", "t3"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    SuperscriptBox["t3", "3"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "3"]}], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"5", " ", "t2"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"10", " ", "t2"}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t2"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          SuperscriptBox["t2", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t2"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", "+", 
           FractionBox["3", 
            RowBox[{"2", " ", "t1"}]], "-", 
           RowBox[{"9", " ", "t1"}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["t1", "2"]}], "-", 
           FractionBox[
            SuperscriptBox["t1", "3"], "2"], "+", 
           RowBox[{"6", " ", 
            RowBox[{"Log", "[", "t1", "]"}]}]}], 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]]}], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t3"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t3", "2"]}], "+", 
          SuperscriptBox["t3", "3"], "-", 
          RowBox[{"6", " ", "t3", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t3"}], ")"}], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"6", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t2"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t2", "3"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"60", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["t2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "t2"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"5", "-", 
                    RowBox[{"3", " ", "t3"}]}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}], " ", "t3"}]}], 
                    ")"}]}], "+", 
                    RowBox[{"t3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}]}], "+", 
                    RowBox[{"t3", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}]}]}], ")"}]}], 
                 "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["t3", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], "+", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}], " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    SuperscriptBox["t3", "3"]}], ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["t1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}], " ", "t3"}], "+", 
                    
                    SuperscriptBox["t3", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"3", "-", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
                    RowBox[{"t1", " ", "t3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["t2", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}], " ", 
                    SuperscriptBox["t3", "3"]}], "+", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"t3", "+", 
                    RowBox[{"6", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"3", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}]}], 
                   ")"}], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.5641736283013887`*^9, 3.5641736440450363`*^9}, 
   3.583471088783399*^9, {3.583471900776719*^9, 3.583471906505773*^9}, {
   3.5835339396629343`*^9, 3.583533942712872*^9}, {3.583542053820417*^9, 
   3.5835420572733517`*^9}, 3.583561670487256*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd23", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["t1", "2"]}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
             RowBox[{"(", 
              RowBox[{"t1", "+", 
               SuperscriptBox["t1", "2"], "-", 
               RowBox[{"3", " ", "t3"}], "+", 
               RowBox[{"t1", " ", "t3"}]}], ")"}], " ", 
             RowBox[{"Log", "[", "t1", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["t3", "3"]}], "+", 
                  RowBox[{"t1", " ", 
                   SuperscriptBox["t3", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", "t3"}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox["t1", "2"], " ", "t3", " ", 
                   RowBox[{"(", 
                    RowBox[{"2", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["t1", "3"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "-", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                SuperscriptBox["t3", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"t1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}]}], "+", 
                  RowBox[{"t3", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}]}], ")"}], " ", 
                RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}], "/", 
         
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "t1", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["t1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"4", " ", "t2"}]}], ")"}]}], "-", 
              RowBox[{"3", " ", "t1", " ", "t2"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["t2", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["t1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"2", "+", "t2"}], ")"}]}]}], ")"}], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"3", " ", "t2"}]}], ")"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["t1", "4"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "-", 
                    RowBox[{"5", " ", "t2"}]}], ")"}], " ", 
                  SuperscriptBox["t2", "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "3"]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "14"}], "+", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t2", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"5", " ", "t3"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "-", 
                 RowBox[{"t2", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3", "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t2"}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t3"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "+", "t2"}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"11", "+", 
                    RowBox[{"7", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", 
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"14", "+", 
                    RowBox[{"3", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", "t2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["t1", "3"]}], "-", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"2", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    SuperscriptBox["t2", "2"]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "-", 
                    RowBox[{"3", " ", "t2"}], "-", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    SuperscriptBox["t2", "3"]}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t3"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"5", " ", "t3"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3", "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t3", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t3", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1"}], "-", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t3"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"12", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"7", " ", "t2"}], "-", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["t2", "2"]}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"12", " ", "t2"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"36", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "-", 
          RowBox[{"6", " ", "t1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t2"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          SuperscriptBox["t2", "3"], "-", 
          RowBox[{"6", " ", "t2", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"12", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        FractionBox[
         RowBox[{"17", "-", 
          RowBox[{"9", " ", "t1"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "+", 
          RowBox[{"6", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", "t1"}]}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t3"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t3", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t3", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t3"}], ")"}], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t2"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t2", "3"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"72", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"72", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"120", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["t1", "3"]}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
               SuperscriptBox["t2", "3"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"t2", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "t3"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"t2", "-", 
                    RowBox[{"2", " ", "t3"}], "+", 
                    RowBox[{"t2", " ", "t3"}]}], ")"}]}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "t3"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}]}]}], 
                   ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "t3"}], ")"}]}], "+", 
                    RowBox[{"2", " ", "t3"}]}], ")"}]}], "-", 
                    RowBox[{"t3", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "t2"}], "+", "t3", "+", 
                    SuperscriptBox["t3", "2"]}], ")"}]}]}], ")"}], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.564173650848362*^9, 3.5641736686441708`*^9}, 
   3.583471088867607*^9, {3.5834719107139683`*^9, 3.583471915265386*^9}, {
   3.583533946090625*^9, 3.583533949212432*^9}, {3.583542061519937*^9, 
   3.583542064812922*^9}, 3.583561673290806*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFant", "[", 
    RowBox[{
    "LoopTools`dd33", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "t1", ",", "t2", ",", "t3", ",", "s12", ",", "s13", ",", "s14", ",", 
       "s23", ",", "s24", ",", "s34", ",", "s12s34", ",", "s13s24", ",", 
       "s14s23", ",", "s123", ",", "s124", ",", "s134", ",", "s234", ",", 
       "s1234", ",", "us"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1", ",", "t2", ",", "t3"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["m1s", "m4s"], ",", 
         FractionBox["m2s", "m4s"], ",", 
         FractionBox["m3s", "m4s"]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s12", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s13", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s14", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m4s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s", ",", "m3s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m3s", ",", "m1s", ",", "m2s"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"s12s34", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s13s24", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s14s23", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s123", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m4s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s124", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m2s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m3s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s134", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m1s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m1s", ",", "m2s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s234", "=", 
       RowBox[{
        RowBox[{"SameQ", "[", 
         RowBox[{"m2s", ",", "m3s", ",", "m4s"}], "]"}], "&&", 
        RowBox[{"UnsameQ", "[", 
         RowBox[{"m2s", ",", "m1s"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"s1234", "=", 
       RowBox[{"SameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"us", "=", 
       RowBox[{"UnsameQ", "[", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{"s12", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t1"}], "+", 
              SuperscriptBox["t1", "2"], "-", 
              RowBox[{"3", " ", "t3"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t3", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t3"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", "t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t3", "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"9", " ", "t3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"7", " ", "t3"}], "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t3"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s13", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["t1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "t1"}], "+", 
              SuperscriptBox["t1", "2"], "-", 
              RowBox[{"3", " ", "t2"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2"}], ")"}]}], "+", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "t2", "-", 
                    RowBox[{"5", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"9", " ", "t2"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t2", "2"]}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s14", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t2", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t2", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"7", " ", "t3"}], "-", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"12", " ", "t3"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s23", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t2", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", 
                    RowBox[{"5", " ", "t2"}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"5", " ", "t2"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "-", 
                 RowBox[{"t1", " ", "t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"9", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2", "+", 
                    RowBox[{"14", " ", 
                    SuperscriptBox["t2", "2"]}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t2", "3"]}]}], ")"}]}]}], ")"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "t1"}], "-", 
                 RowBox[{"t2", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", "t2"}], ")"}]}]}], ")"}], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"t1", "-", "t2"}], ")"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s24", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["t1", "3"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"7", " ", "t3"}], "-", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t3", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"5", " ", "t3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["t3", "2"]}]}], ")"}]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["t3", "2"]}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"12", " ", "t3"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t3", "3"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"6", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t3", "3"], " ", 
               RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"18", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s34", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                FractionBox["1", "3"]}], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"5", " ", "t2"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["t2", "2"]}], "+", 
                 RowBox[{"t1", " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"10", " ", "t2"}], "-", 
                    RowBox[{"7", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}], "+", 
                 RowBox[{
                  SuperscriptBox["t1", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "-", 
                    RowBox[{"7", " ", "t2"}], "+", 
                    RowBox[{"11", " ", 
                    SuperscriptBox["t2", "2"]}]}], ")"}]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}]}], ")"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "4"]}], ")"}]}], ",", 
        "\[IndentingNewLine]", "s12s34", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s13s24", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s14s23", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"9", " ", "t2"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t2", "2"]}], "-", 
          RowBox[{"17", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["t2", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "t2"}], ")"}], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"18", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s123", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "-", 
          RowBox[{"9", " ", "t1"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          SuperscriptBox["t1", "3"], "-", 
          RowBox[{"6", " ", "t1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "t1"}], ")"}], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"6", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s124", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t3"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t3", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t3", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t3", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t3", "3"], " ", 
           RowBox[{"Log", "[", "t3", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t3"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s134", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t2"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t2", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t2", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t2", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t2", "3"], " ", 
           RowBox[{"Log", "[", "t2", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s234", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"6", " ", "t1"}], "-", 
          RowBox[{"18", " ", 
           SuperscriptBox["t1", "2"]}], "+", 
          RowBox[{"10", " ", 
           SuperscriptBox["t1", "3"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["t1", "4"]}], "-", 
          RowBox[{"12", " ", 
           SuperscriptBox["t1", "3"], " ", 
           RowBox[{"Log", "[", "t1", "]"}]}]}], 
         RowBox[{"36", " ", 
          SuperscriptBox["m4s", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t1"}], ")"}], "5"]}]], ",", 
        "\[IndentingNewLine]", "s1234", ",", 
        FractionBox["1", 
         RowBox[{"60", " ", 
          SuperscriptBox["m4s", "2"]}]], ",", "\[IndentingNewLine]", "us", 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["t1", "3"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
            RowBox[{"(", 
             RowBox[{"t2", "-", "t3"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
            RowBox[{"Log", "[", "t1", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
               SuperscriptBox["t2", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"t1", "-", "t3"}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"], " ", 
               RowBox[{"Log", "[", "t2", "]"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"t1", "-", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"t1", "-", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "t2"}], "+", "t3"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "t2", "+", "t3", "-", 
                    RowBox[{"3", " ", "t2", " ", "t3"}], "+", 
                    RowBox[{"t1", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"3", " ", "t3"}], "+", 
                    RowBox[{"t2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"5", " ", "t3"}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
                  "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t1"}], ")"}], "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "t2"}], ")"}], "2"], " ", 
                  SuperscriptBox["t3", "3"], " ", 
                  RowBox[{"Log", "[", "t3", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"6", " ", 
           SuperscriptBox["m4s", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t1"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t2"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{"t1", "-", "t3"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"t2", "-", "t3"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t3"}], ")"}], "3"]}], ")"}]}]}], 
       "]"}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.564173680984867*^9, 3.56417368353441*^9}, 
   3.583471088948732*^9, {3.583471919358922*^9, 3.5834719227955847`*^9}, {
   3.5835339523908567`*^9, 3.5835339561466703`*^9}, {3.583542069215562*^9, 
   3.583542073113701*^9}, 3.583561676304255*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DFDant", "[", 
    RowBox[{
    "id_", ",", " ", "p1s_", ",", " ", "p2s_", ",", " ", "p3s_", ",", " ", 
     "p4s_", ",", " ", "p12s_", ",", " ", "p23s_", ",", " ", "m1s_", ",", " ",
      "m2s_", ",", " ", "m3s_", ",", " ", "m4s_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", " ", 
     RowBox[{
      RowBox[{
      "Print", "[", "\"\<Derivative for D0i not implemented\>\"", "]"}], ";", 
      " ", 
      RowBox[{
       RowBox[{"D0i", "[", 
        RowBox[{
        "id", ",", " ", "p1s", ",", " ", "p2s", ",", " ", "p3s", ",", " ", 
         "p4s", ",", " ", "p12s", ",", " ", "p23s", ",", " ", "m1s", ",", " ",
          "m3s", ",", " ", "m3s", ",", " ", "m4s"}], "]"}], " ", "-", " ", 
       RowBox[{"DFant", "[", 
        RowBox[{
        "id", ",", " ", "m1s", ",", " ", "m2s", ",", " ", "m3s", ",", " ", 
         "m4s"}], "]"}]}]}]}], "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.5834719295249777`*^9, 3.583472115149555*^9}, {
  3.583472151105317*^9, 3.583472151504211*^9}, {3.583481868318366*^9, 
  3.583481906127993*^9}, {3.5834819534813833`*^9, 3.583482010349678*^9}, {
  3.58348312211169*^9, 3.583483129596859*^9}, {3.583533556381955*^9, 
  3.583533564130041*^9}, {3.583533964038224*^9, 3.583533972113387*^9}, {
  3.583542089049097*^9, 3.583542099347761*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["The Main Functions", "Subsection",
 CellChangeTimes->{{3.5641730923050833`*^9, 3.564173096000548*^9}, {
  3.564727919610579*^9, 3.56472792086478*^9}, {3.58346609515847*^9, 
  3.583466101663528*^9}, {3.583483034888692*^9, 3.583483050699627*^9}, {
  3.583558914531926*^9, 3.583558918114999*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ANT", "[", "expr_", "]"}], ":=", 
   RowBox[{"ReleaseHold", "[", 
    RowBox[{"expr", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A0", "\[RuleDelayed]", "A0ant"}], ",", 
       RowBox[{"B0i", ":>", "B0ant"}], ",", 
       RowBox[{"C0i", "\[RuleDelayed]", "C0ant"}], ",", 
       RowBox[{"D0i", "\[RuleDelayed]", "D0ant"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Code",
 CellChangeTimes->{
  3.583472709728491*^9, {3.5834727843334093`*^9, 3.583472785372573*^9}, {
   3.583472913918058*^9, 3.583472946431559*^9}, {3.583472982564592*^9, 
   3.583473011987817*^9}, {3.583473189665059*^9, 3.583473193714664*^9}, {
   3.583476845012698*^9, 3.583476865314459*^9}, {3.583476896603477*^9, 
   3.5834770298583603`*^9}, {3.583477102898736*^9, 3.583477278066091*^9}, {
   3.5834774787129602`*^9, 3.583477589494581*^9}, {3.583477645092669*^9, 
   3.5834780009321613`*^9}, {3.5834780381836*^9, 3.583478055403754*^9}, {
   3.583478092523954*^9, 3.583478092667625*^9}, {3.583478123804146*^9, 
   3.5834781871788263`*^9}, {3.5834788761684027`*^9, 
   3.5834791460043592`*^9}, {3.583479187004944*^9, 3.583479294278254*^9}, {
   3.58347963318288*^9, 3.583479639291904*^9}, {3.58347992309389*^9, 
   3.583480190797441*^9}, {3.583480233026416*^9, 3.583480267740027*^9}, {
   3.5834803010571213`*^9, 3.583480314249148*^9}, {3.583480358452663*^9, 
   3.583480465350836*^9}, {3.5834809325641823`*^9, 3.583481094845825*^9}, {
   3.583481127441926*^9, 3.583481387020152*^9}, {3.583481445980418*^9, 
   3.583481457084104*^9}, {3.583481501901288*^9, 3.583481608019031*^9}, {
   3.583481639029619*^9, 3.583481669494226*^9}, {3.583481727530859*^9, 
   3.583481767251313*^9}, {3.58348185110756*^9, 3.583481861587051*^9}, {
   3.583482104889333*^9, 3.5834822531725492`*^9}, {3.58348228654883*^9, 
   3.583482287451687*^9}, {3.583482351468184*^9, 3.583482467573001*^9}, {
   3.5834825156073217`*^9, 3.583482530230503*^9}, {3.583482656946245*^9, 
   3.583482658532668*^9}, {3.583483249896345*^9, 3.583483274051214*^9}, {
   3.5834834268873453`*^9, 3.583483478179517*^9}, {3.583483557311281*^9, 
   3.583483570050612*^9}, {3.583483600635631*^9, 3.583483645220439*^9}, {
   3.583483773697817*^9, 3.583483811007072*^9}, {3.58348384820827*^9, 
   3.583483940502008*^9}, {3.58348401046056*^9, 3.583484148594351*^9}, {
   3.583484262006524*^9, 3.58348427552709*^9}, {3.5834847938655977`*^9, 
   3.5834848661208973`*^9}, {3.583484902561891*^9, 3.583484906867227*^9}, {
   3.583484952505879*^9, 3.583484965313408*^9}, {3.583485012667123*^9, 
   3.5834851205574427`*^9}, {3.583485195543921*^9, 3.583485288247493*^9}, {
   3.5834853684778147`*^9, 3.583485370386286*^9}, {3.583485620088086*^9, 
   3.583485695817154*^9}, {3.583539600394081*^9, 3.583539629404092*^9}, {
   3.5835404136947536`*^9, 3.583540440807715*^9}, {3.58354047825762*^9, 
   3.5835404831737223`*^9}, {3.583540521634224*^9, 3.583540596550061*^9}, {
   3.583540705062231*^9, 3.583540737230472*^9}, {3.583540797183695*^9, 
   3.583540811604257*^9}, {3.583540950491946*^9, 3.583540951061165*^9}, {
   3.583541278032175*^9, 3.583541279531176*^9}, {3.583543427193491*^9, 
   3.583543447105885*^9}, {3.5835434942375193`*^9, 3.5835435234786873`*^9}, {
   3.58354397570776*^9, 3.583543982482918*^9}, {3.583544652732439*^9, 
   3.583544653728846*^9}, 3.58354476510643*^9, {3.58356072888447*^9, 
   3.583560738362537*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A0ant", "[", "ms_", "]"}], ":=", 
   RowBox[{"AFant", "[", "ms", "]"}]}], ";"}]], "Code",
 CellChangeTimes->{{3.583560270009886*^9, 3.58356027647679*^9}, {
  3.583560372984733*^9, 3.583560373478619*^9}, {3.5835604984733267`*^9, 
  3.5835605020510283`*^9}, {3.5835607112788563`*^9, 3.583560712368835*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"B0ant", "[", 
    RowBox[{"id_", ",", "ps_", ",", "m1s_", ",", "m2s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mas", ",", "mom", ",", "tmas", ",", "rmas", ",", "mas0", ",", "mas1", 
       ",", "expr", ",", "exprD", ",", "x1", ",", "x2"}], "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"id", "===", "LoopTools`bb00"}], "||", 
           RowBox[{"id", "===", "LoopTools`bb11"}]}], ")"}], "\[And]", 
         RowBox[{"ps", "=!=", "0"}]}], ",", "\n", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Derivative for B0i[\>\"", ",", "id", ",", 
           "\"\<] not implemented\>\""}], "]"}], ";", "\n", 
         RowBox[{"Return", "[", 
          RowBox[{"B0i", "[", 
           RowBox[{"id", ",", " ", "ps", ",", " ", "m1s", ",", " ", "m2s"}], 
           "]"}], "]"}], ";"}]}], "\n", "]"}], ";", "\n", 
      RowBox[{"mas", "=", 
       RowBox[{"{", 
        RowBox[{"m1s", ",", "m2s"}], "}"}]}], ";", "\n", 
      RowBox[{"tmas", "=", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "x2"}], "}"}]}], ";", "\n", 
      RowBox[{"rmas", "=", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"tmas", ",", "mas"}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"mas0", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
         RowBox[{"Cases", "[", 
          RowBox[{"rmas", ",", 
           RowBox[{"{", 
            RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"mas1", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
         RowBox[{"DeleteCases", "[", 
          RowBox[{"rmas", ",", 
           RowBox[{"{", 
            RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"tmas", "=", 
       RowBox[{"tmas", "/.", "mas1"}]}], ";", "\n", 
      RowBox[{"expr", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"BFant", ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"{", 
           RowBox[{"id", ",", "tmas"}], "}"}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"expr", "=", 
       RowBox[{"Fold", "[", 
        RowBox[{"Limit", ",", "expr", ",", "mas0"}], "]"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"ps", "=!=", "0"}], ",", "\n", 
        RowBox[{
         RowBox[{"exprD", "=", 
          RowBox[{"Apply", "[", 
           RowBox[{"BFDant", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{"id", ",", "ps", ",", "tmas"}], "}"}], "]"}]}], "]"}]}],
          ";", "\n", 
         RowBox[{"expr", "=", 
          RowBox[{"expr", "+", 
           RowBox[{"Fold", "[", 
            RowBox[{"Limit", ",", "exprD", ",", "mas0"}], "]"}]}]}], ";"}]}], 
       "\n", "]"}], ";", "\n", 
      RowBox[{"Return", "[", "expr", "]"}], ";"}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellChangeTimes->{{3.583542248346862*^9, 3.583542290550412*^9}, {
   3.5835423215748863`*^9, 3.583542399541288*^9}, {3.5835424304268713`*^9, 
   3.583542457451857*^9}, {3.583542496452364*^9, 3.5835424997423973`*^9}, {
   3.58354282635436*^9, 3.583543238477845*^9}, {3.583543342550386*^9, 
   3.583543348792695*^9}, 3.5835437090418243`*^9, {3.58354385347305*^9, 
   3.583543877681316*^9}, {3.583544577368105*^9, 3.583544620899125*^9}, {
   3.583545912805382*^9, 3.5835459161810703`*^9}, {3.58354597986086*^9, 
   3.583546024225926*^9}, {3.5835460559302998`*^9, 3.5835461248869143`*^9}, {
   3.583546218498728*^9, 3.583546223251554*^9}, {3.5835587662235727`*^9, 
   3.583558766554096*^9}, {3.583560281605072*^9, 3.583560283013749*^9}, {
   3.583560367173953*^9, 3.583560371103314*^9}, {3.583560537574478*^9, 
   3.583560548452105*^9}, {3.583560699695558*^9, 3.583560704180943*^9}, {
   3.5835610030923223`*^9, 3.583561013274876*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"C0ant", "[", 
    RowBox[{
    "id_", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", ",", "m2s_", 
     ",", "m3s_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mas", ",", "mom", ",", "tmas", ",", "mas0", ",", "mas1", ",", "expr", 
       ",", "exprD", ",", "x1", ",", "x2", ",", "x3", ",", "talMas"}], "}"}], 
     ",", "\n", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{"p1s", "===", "0"}], "\[And]", 
           RowBox[{"p2s", "===", "0"}], "\[And]", 
           RowBox[{"p12s", "===", "0"}]}], "]"}], "\[And]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"id", "===", "LoopTools`cc001"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc002"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc111"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc112"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc121"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc211"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc122"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc221"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc212"}], "||", 
           RowBox[{"id", "===", "LoopTools`cc222"}]}], ")"}]}], ",", "\n", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Derivative for C0i[\>\"", ",", "id", ",", 
           "\"\<] not implemented\>\""}], "]"}], ";", "\n", 
         RowBox[{"Return", "[", 
          RowBox[{"C0i", "[", 
           RowBox[{
           "id", ",", " ", "p1s", ",", " ", "p2s", ",", " ", "p12s", ",", " ",
             "m1s", ",", " ", "m2s", ",", " ", "m3s"}], "]"}], "]"}]}]}], 
       "\n", "]"}], ";", "\n", 
      RowBox[{"mas", "=", 
       RowBox[{"{", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "}"}]}], ";", "\n", 
      RowBox[{"tmas", "=", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "x2", ",", "x3"}], "}"}]}], ";", "\n", 
      RowBox[{"talMas", "=", 
       RowBox[{"Tally", "[", "mas", "]"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "talMas", "]"}], "==", "3"}], ",", "\n", 
        RowBox[{"Block", "[", 
         RowBox[{
          RowBox[{"{", "rmas", "}"}], ",", "\n", 
          RowBox[{
           RowBox[{"rmas", "=", 
            RowBox[{"MapThread", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
              RowBox[{"{", 
               RowBox[{"tmas", ",", "mas"}], "}"}]}], "]"}]}], ";", "\n", 
           RowBox[{"mas0", "=", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "->", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
              RowBox[{"Cases", "[", 
               RowBox[{"rmas", ",", 
                RowBox[{"{", 
                 RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", 
           "\n", 
           RowBox[{"mas1", "=", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "->", 
                RowBox[{"#", "[", 
                 RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
              RowBox[{"DeleteCases", "[", 
               RowBox[{"rmas", ",", 
                RowBox[{"{", 
                 RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}]}]}], 
         "]"}], ",", "\n", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "talMas", "]"}], "==", "1"}], ",", "\n", 
           RowBox[{
            RowBox[{"mas0", "=", 
             RowBox[{"MapThread", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"#1", "->", "#2"}], "&"}], ",", 
               RowBox[{"{", 
                RowBox[{"tmas", ",", "mas"}], "}"}]}], "]"}]}], ";", "\n", 
            RowBox[{"mas1", "=", 
             RowBox[{"{", "}"}]}], ";"}]}], "\n", "]"}], ";", "\n", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "talMas", "]"}], "==", "2"}], ",", "\n", 
           RowBox[{
            RowBox[{"Block", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"temp", ",", "pos", ",", "rmas"}], "}"}], ",", "\n", 
              RowBox[{
               RowBox[{"temp", "=", 
                RowBox[{
                 RowBox[{"Select", "[", 
                  RowBox[{"talMas", ",", " ", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], " ", "==", " ", "2"}], 
                    " ", "&"}]}], "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\n", 
               RowBox[{"pos", "=", 
                RowBox[{"Flatten", "[", 
                 RowBox[{"Position", "[", 
                  RowBox[{"mas", ",", "temp"}], "]"}], "]"}]}], ";", "\n", 
               RowBox[{"rmas", "=", 
                RowBox[{"MapThread", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"tmas", ",", "mas"}], "}"}]}], "]"}]}], ";", "\n", 
               
               RowBox[{"mas0", "=", 
                RowBox[{"Map", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "->", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
                  RowBox[{"rmas", "[", 
                   RowBox[{"[", "pos", "]"}], "]"}]}], "]"}]}], ";", "\n", 
               RowBox[{"rmas", "=", 
                RowBox[{"rmas", "[", 
                 RowBox[{"[", 
                  RowBox[{"Complement", "[", 
                   RowBox[{
                    RowBox[{"Range", "[", "3", "]"}], ",", "pos"}], "]"}], 
                  "]"}], "]"}]}], ";", "\n", 
               RowBox[{"mas0", "=", 
                RowBox[{"Join", "[", 
                 RowBox[{"mas0", ",", 
                  RowBox[{"Map", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "->", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
                    RowBox[{"Cases", "[", 
                    RowBox[{"rmas", ",", 
                    RowBox[{"{", 
                    RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], 
                 "]"}]}], ";", "\n", 
               RowBox[{"mas1", "=", 
                RowBox[{"Map", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "->", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
                  RowBox[{"DeleteCases", "[", 
                   RowBox[{"rmas", ",", 
                    RowBox[{"{", 
                    RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}]}]}], 
             "]"}], ";"}]}], "\n", "]"}]}]}], "]"}], ";", "\n", 
      RowBox[{"tmas", "=", 
       RowBox[{"tmas", "/.", "mas1"}]}], ";", "\n", 
      RowBox[{"expr", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"CFant", ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"{", 
           RowBox[{"id", ",", "tmas"}], "}"}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"expr", "=", 
       RowBox[{"Fold", "[", 
        RowBox[{"Limit", ",", "expr", ",", "mas0"}], "]"}]}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{
          RowBox[{"p1s", "===", "0"}], "\[And]", 
          RowBox[{"p2s", "===", "0"}], "\[And]", 
          RowBox[{"p12s", "===", "0"}]}], "]"}], ",", "\n", 
        RowBox[{
         RowBox[{"exprD", "=", 
          RowBox[{"Apply", "[", 
           RowBox[{"CFDant", ",", 
            RowBox[{"Flatten", "[", 
             RowBox[{"{", 
              RowBox[{"id", ",", 
               RowBox[{"{", 
                RowBox[{"p1s", ",", "p2s", ",", "p12s"}], "}"}], ",", 
               "tmas"}], "}"}], "]"}]}], "]"}]}], ";", "\n", 
         RowBox[{"expr", "=", 
          RowBox[{"expr", "+", 
           RowBox[{"Fold", "[", 
            RowBox[{"Limit", ",", "exprD", ",", "mas0"}], "]"}]}]}], ";"}]}], 
       "\n", "]"}], ";", "\n", 
      RowBox[{"Return", "[", "expr", "]"}], ";"}]}], "\n", "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"C0ant", "[", 
      RowBox[{
      "id_", ",", "p1s_", ",", "p2s_", ",", "p12s_", ",", "m1s_", ",", "m2s_",
        ",", "m3s_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "mas", ",", "mom", ",", "tmas", ",", "rmas", ",", "mas0", ",", "mas1",
          ",", "expr", ",", "exprD", ",", "x1", ",", "x2", ",", "x3"}], "}"}],
        ",", "\n", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"id", "===", "LoopTools`cc22"}], "||", 
             RowBox[{"id", "===", "LoopTools`cc12"}], "||", 
             RowBox[{"id", "===", "LoopTools`cc11"}]}], ")"}], "\[And]", 
           RowBox[{"Not", "[", 
            RowBox[{
             RowBox[{"p1s", "===", "0"}], "\[And]", 
             RowBox[{"p2s", "===", "0"}], "\[And]", 
             RowBox[{"p12s", "===", "0"}]}], "]"}]}], ",", "\n", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
            "\"\<Derivative for C0i[\>\"", ",", "id", ",", 
             "\"\<] not implemented\>\""}], "]"}], ";", "\n", 
           RowBox[{"Return", "[", 
            RowBox[{"C0i", "[", 
             RowBox[{
             "id", ",", " ", "p1s", ",", " ", "p2s", ",", " ", "p12s", ",", 
              " ", "m1s", ",", " ", "m2s", ",", " ", "m3s"}], "]"}], 
            "]"}]}]}], "\n", "]"}], ";", "\n", 
        RowBox[{"mas", "=", 
         RowBox[{"{", 
          RowBox[{"m1s", ",", "m2s", ",", "m3s"}], "}"}]}], ";", "\n", 
        RowBox[{"tmas", "=", 
         RowBox[{"{", 
          RowBox[{"x1", ",", "x2", ",", "x3"}], "}"}]}], ";", "\n", 
        RowBox[{"rmas", "=", 
         RowBox[{"MapThread", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
           RowBox[{"{", 
            RowBox[{"tmas", ",", "mas"}], "}"}]}], "]"}]}], ";", "\n", 
        RowBox[{"mas0", "=", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
           RowBox[{"Cases", "[", 
            RowBox[{"rmas", ",", 
             RowBox[{"{", 
              RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
        RowBox[{"mas1", "=", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
           RowBox[{"DeleteCases", "[", 
            RowBox[{"rmas", ",", 
             RowBox[{"{", 
              RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
        RowBox[{"tmas", "=", 
         RowBox[{"tmas", "/.", "mas1"}]}], ";", "\n", 
        RowBox[{"expr", "=", 
         RowBox[{"Apply", "[", 
          RowBox[{"CFant", ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{"id", ",", "tmas"}], "}"}], "]"}]}], "]"}]}], ";", "\n", 
        
        RowBox[{"expr", "=", 
         RowBox[{"Fold", "[", 
          RowBox[{"Limit", ",", "expr", ",", "mas0"}], "]"}]}], ";", "\n", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"Not", "[", 
           RowBox[{
            RowBox[{"p1s", "===", "0"}], "\[And]", 
            RowBox[{"p2s", "===", "0"}], "\[And]", 
            RowBox[{"p12s", "===", "0"}]}], "]"}], ",", "\n", 
          RowBox[{
           RowBox[{"exprD", "=", 
            RowBox[{"Apply", "[", 
             RowBox[{"CFDant", ",", 
              RowBox[{"Flatten", "[", 
               RowBox[{"{", 
                RowBox[{"id", ",", 
                 RowBox[{"{", 
                  RowBox[{"p1s", ",", "p2s", ",", "p12s"}], "}"}], ",", 
                 "tmas"}], "}"}], "]"}]}], "]"}]}], ";", "\n", 
           RowBox[{"expr", "=", 
            RowBox[{"expr", "+", 
             RowBox[{"Fold", "[", 
              RowBox[{"Limit", ",", "exprD", ",", "mas0"}], "]"}]}]}], 
           ";"}]}], "\n", "]"}], ";", "\n", 
        RowBox[{"Return", "[", "expr", "]"}], ";"}]}], "\n", "]"}]}], ";"}], 
   "*)"}]}]}], "Code",
 CellChangeTimes->{{3.583542248346862*^9, 3.583542290550412*^9}, {
   3.5835423215748863`*^9, 3.583542399541288*^9}, {3.5835424304268713`*^9, 
   3.583542457451857*^9}, {3.583542496452364*^9, 3.5835424997423973`*^9}, {
   3.58354282635436*^9, 3.583543327479999*^9}, {3.583543944168198*^9, 
   3.583543949633074*^9}, {3.583544472153756*^9, 3.5835445577187357`*^9}, {
   3.583544639247466*^9, 3.583544640074057*^9}, {3.583546147678376*^9, 
   3.583546183404258*^9}, {3.583559739461548*^9, 3.583559739653452*^9}, {
   3.583560286197299*^9, 3.583560287367743*^9}, {3.58356036002332*^9, 
   3.5835603636173773`*^9}, {3.583560552230321*^9, 3.58356056208925*^9}, {
   3.583560686434907*^9, 3.583560691604714*^9}, {3.583561017420804*^9, 
   3.5835610292462797`*^9}, {3.604971656681184*^9, 3.6049718041572*^9}, {
   3.604971851955735*^9, 3.604971852356715*^9}, 3.604972100314652*^9, {
   3.604972168642695*^9, 3.6049721967206507`*^9}, {3.6049722964793673`*^9, 
   3.6049723682258167`*^9}, {3.604972840723633*^9, 3.604972872510865*^9}, {
   3.604972918341868*^9, 3.6049729197278214`*^9}, {3.604972962008391*^9, 
   3.604973027093363*^9}, {3.604973366453977*^9, 3.604973375489841*^9}, {
   3.604973445265926*^9, 3.6049734455567904`*^9}, 3.60497349708179*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D0ant", "[", 
    RowBox[{
    "id_", ",", "p1s_", ",", "p2s_", ",", "p3s_", ",", "p4s_", ",", "p12s_", 
     ",", "p23s_", ",", "m1s_", ",", "m2s_", ",", "m3s_", ",", "m4s_"}], 
    "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mas", ",", "mom", ",", "tmas", ",", "rmas", ",", "mas0", ",", "mas1", 
       ",", "expr", ",", "exprD", ",", "x1", ",", "x2", ",", "x3", ",", 
       "x4"}], "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{
          RowBox[{"p1s", "===", "0"}], "\[And]", 
          RowBox[{"p2s", "===", "0"}], "\[And]", 
          RowBox[{"p3s", "===", "0"}], "\[And]", 
          RowBox[{"p4s", "===", "0"}], "\[And]", 
          RowBox[{"p12s", "===", "0"}], "\[And]", 
          RowBox[{"p23s", "===", "0"}]}], "]"}], ",", "\n", 
        RowBox[{
         RowBox[{
         "Print", "[", "\"\<Derivative for D0i not implemented\>\"", "]"}], 
         ";", "\n", 
         RowBox[{"Return", "[", 
          RowBox[{"D0i", "[", 
           RowBox[{
           "id", ",", " ", "p1s", ",", " ", "p2s", ",", " ", "p3s", ",", " ", 
            "p4s", ",", " ", "p12s", ",", " ", "p23s", ",", " ", "m1s", ",", 
            " ", "m3s", ",", " ", "m3s", ",", " ", "m4s"}], "]"}], "]"}]}]}], 
       "\n", "]"}], ";", "\n", 
      RowBox[{"mas", "=", 
       RowBox[{"{", 
        RowBox[{"m1s", ",", "m2s", ",", "m3s", ",", "m4s"}], "}"}]}], ";", 
      "\n", 
      RowBox[{"tmas", "=", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "x2", ",", "x3", ",", "x4"}], "}"}]}], ";", "\n", 
      RowBox[{"rmas", "=", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"#1", ",", "#2"}], "}"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"tmas", ",", "mas"}], "}"}]}], "]"}]}], ";", "\n", 
      RowBox[{"mas0", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
         RowBox[{"Cases", "[", 
          RowBox[{"rmas", ",", 
           RowBox[{"{", 
            RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"mas1", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "&"}], ",", 
         RowBox[{"DeleteCases", "[", 
          RowBox[{"rmas", ",", 
           RowBox[{"{", 
            RowBox[{"_", ",", "0"}], "}"}]}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"tmas", "=", 
       RowBox[{"tmas", "/.", "mas1"}]}], ";", "\n", 
      RowBox[{"expr", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"DFant", ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"{", 
           RowBox[{"id", ",", "tmas"}], "}"}], "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"expr", "=", 
       RowBox[{"Fold", "[", 
        RowBox[{"Limit", ",", "expr", ",", "mas0"}], "]"}]}], ";", "\n", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"exprD", "=", 
         RowBox[{"Apply", "[", 
          RowBox[{"`Private`DFDant", ",", 
           RowBox[{"Flatten", "[", 
            RowBox[{"{", 
             RowBox[{"id", ",", 
              RowBox[{"{", 
               RowBox[{
               "p1s", ",", "p2s", ",", "p3s", ",", "p4s", ",", "p12s", ",", 
                "p23s"}], "}"}], ",", "tmas"}], "}"}], "]"}]}], "]"}]}], ";", 
        "\n", 
        RowBox[{"exprD", "=", 
         RowBox[{"Fold", "[", 
          RowBox[{"Limit", ",", "exprD", ",", "mas0"}], "]"}]}], ";"}], 
       "*)"}], "\n", 
      RowBox[{"Return", "[", "expr", "]"}], ";"}]}], "\n", "]"}]}], 
  ";"}]], "Code",
 CellChangeTimes->{{3.583542248346862*^9, 3.583542290550412*^9}, {
   3.5835423215748863`*^9, 3.583542399541288*^9}, {3.5835424304268713`*^9, 
   3.583542457451857*^9}, {3.583542496452364*^9, 3.5835424997423973`*^9}, {
   3.58354282635436*^9, 3.583543327479999*^9}, {3.583543366772895*^9, 
   3.583543412925329*^9}, {3.5835439621463737`*^9, 3.583543965649255*^9}, {
   3.583544088644062*^9, 3.583544091804872*^9}, {3.583544203587311*^9, 
   3.583544234315922*^9}, {3.583544264458028*^9, 3.58354441455899*^9}, {
   3.583559735914826*^9, 3.583559736165403*^9}, {3.583560290321579*^9, 
   3.5835602951552973`*^9}, 3.583560357087811*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 1014},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (February 7, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 1881, 41, 202, "Code"],
Cell[2441, 63, 4718, 91, 321, "Code"],
Cell[CellGroupData[{
Cell[7184, 158, 147, 2, 98, "Section"],
Cell[CellGroupData[{
Cell[7356, 164, 91, 1, 54, "Subsection"],
Cell[7450, 167, 1011, 22, 265, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[8498, 194, 91, 1, 43, "Subsection"],
Cell[8592, 197, 2067, 57, 468, "Code"],
Cell[10662, 256, 2889, 83, 516, "Code"],
Cell[13554, 341, 1734, 44, 512, "Code"],
Cell[15291, 387, 1974, 55, 315, "Code"],
Cell[17268, 444, 684, 19, 315, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[17989, 468, 90, 1, 43, "Subsection"],
Cell[18082, 471, 17873, 470, 1010, "Code"],
Cell[35958, 943, 22397, 580, 938, "Code"],
Cell[58358, 1525, 21116, 552, 955, "Code"],
Cell[79477, 2079, 20223, 535, 898, "Code"],
Cell[99703, 2616, 22838, 592, 601, "Code"],
Cell[122544, 3210, 22996, 597, 546, "Code"],
Cell[145543, 3809, 23665, 606, 561, "Code"],
Cell[169211, 4417, 1523, 33, 110, "Code"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170771, 4455, 91, 1, 54, "Subsection"],
Cell[170865, 4458, 19388, 532, 2563, "Code"],
Cell[190256, 4992, 27940, 744, 2401, "Code"],
Cell[218199, 5738, 25873, 688, 2675, "Code"],
Cell[244075, 6428, 25787, 688, 2577, "Code"],
Cell[269865, 7118, 20149, 544, 2856, "Code"],
Cell[290017, 7664, 36927, 941, 2772, "Code"],
Cell[326947, 8607, 35346, 916, 2753, "Code"],
Cell[362296, 9525, 33604, 873, 2737, "Code"],
Cell[395903, 10400, 35778, 919, 2753, "Code"],
Cell[431684, 11321, 33192, 863, 2737, "Code"],
Cell[464879, 12186, 31100, 810, 2825, "Code"],
Cell[495982, 12998, 1376, 30, 156, "Code"]
}, Closed]],
Cell[CellGroupData[{
Cell[497395, 13033, 299, 4, 43, "Subsection"],
Cell[497697, 13039, 3389, 54, 63, "Code"],
Cell[501089, 13095, 351, 7, 63, "Code"],
Cell[501443, 13104, 4470, 110, 478, "Code"],
Cell[505916, 13216, 14837, 362, 1306, "Code"],
Cell[520756, 13580, 4618, 116, 432, "Code"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
